# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        Account,
        AccountRolesItem,
        AccountUserRole,
        AccountUserRoleRole,
        AccountUserRolesResponse,
        AccountsResponse,
        AddAssetResponse,
        AddAssetResponseData,
        AssetCommon,
        AssetCommonType,
        AssetCommonWithIncludes,
        AssetCommonWithIncludesType,
        AssetInclude,
        AssetShareParams,
        AssetShareParamsAccess,
        AssetWithIncludes,
        AssetWithIncludes_File,
        AssetWithIncludes_Folder,
        AssetWithIncludes_VersionStack,
        AuditLogsInclude,
        AuditLogsWithIncludesResponse,
        AuditLogwithIncludes,
        AuditLogwithIncludesEventType,
        AuditLogwithIncludesResourceType,
        BadRequest,
        BadRequestErrorsItem,
        BadRequestErrorsItemSource,
        BooleanValue,
        ChildrenType,
        Comment,
        CommentInclude,
        CommentResponse,
        CommentWithIncludes,
        CommentWithIncludesResponse,
        CommentsWithIncludesResponse,
        Conflict,
        ConflictErrorsItem,
        ConflictErrorsItemSource,
        DateDefinition,
        DateDefinitionFieldConfiguration,
        DateDefinitionFieldConfigurationDisplayFormat,
        DateDefinitionFieldConfigurationTimeFormat,
        DateDefinitionFieldType,
        DateDefinitionParams,
        DateDefinitionParamsFieldConfiguration,
        DateDefinitionParamsFieldConfigurationDisplayFormat,
        DateDefinitionParamsFieldConfigurationTimeFormat,
        DateDefinitionWithIncludes,
        DateValue,
        Email,
        EmptyJson,
        FieldDefinition,
        FieldDefinitionInclude,
        FieldDefinitionResponse,
        FieldDefinitionWithIncludes,
        FieldDefinitionWithIncludes_Date,
        FieldDefinitionWithIncludes_LongText,
        FieldDefinitionWithIncludes_Number,
        FieldDefinitionWithIncludes_Rating,
        FieldDefinitionWithIncludes_Select,
        FieldDefinitionWithIncludes_SelectMulti,
        FieldDefinitionWithIncludes_Text,
        FieldDefinitionWithIncludes_Toggle,
        FieldDefinitionWithIncludes_UserMulti,
        FieldDefinitionWithIncludes_UserSingle,
        FieldDefinition_Date,
        FieldDefinition_LongText,
        FieldDefinition_Number,
        FieldDefinition_Rating,
        FieldDefinition_Select,
        FieldDefinition_SelectMulti,
        FieldDefinition_Text,
        FieldDefinition_Toggle,
        FieldDefinition_UserMulti,
        FieldDefinition_UserSingle,
        FieldDefinitionsWithIncludesResponse,
        FieldValueCommon,
        File,
        FileAssetsWithIncludesResponse,
        FileCopyResponse,
        FileRemoteUploadResponse,
        FileResponse,
        FileSort,
        FileStatus,
        FileUploadStatus,
        FileUploadStatusResponse,
        FileWithIncludes,
        FileWithIncludesResponse,
        FileWithIncludesStatus,
        FileWithMediaLinksInclude,
        FileWithUploadUrls,
        FileWithUploadUrlsResponse,
        Filters,
        FiltersEventType,
        FiltersResourceType,
        Folder,
        FolderAssetsWithIncludesResponse,
        FolderCopyResponse,
        FolderResponse,
        FolderWithIncludes,
        FolderWithIncludesResponse,
        FoldersWithIncludesResponse,
        Forbidden,
        ForbiddenErrorsItem,
        ForbiddenErrorsItemSource,
        Include,
        IncludeTotalCount,
        IntegerValue,
        JsonErrorResponse,
        JsonErrorResponseErrorsItem,
        JsonErrorResponseErrorsItemSource,
        Links,
        LongTextDefinition,
        LongTextDefinitionFieldConfiguration,
        LongTextDefinitionFieldType,
        LongTextDefinitionParams,
        LongTextDefinitionWithIncludes,
        MediaLinkCommon,
        MediaLinksCollection,
        MetadataField,
        MetadataField_Date,
        MetadataField_LongText,
        MetadataField_Number,
        MetadataField_Rating,
        MetadataField_Select,
        MetadataField_SelectMulti,
        MetadataField_Text,
        MetadataField_Toggle,
        MetadataField_UserMulti,
        MetadataField_UserSingle,
        MetadataField_Users,
        MetadataResponse,
        MetadataWithDefinition,
        MultiSelectValue,
        MultiUserValue,
        MultiUserValueMemberOptionsType,
        NoContent,
        NotFound,
        NotFoundErrorsItem,
        NotFoundErrorsItemSource,
        NumberDefinition,
        NumberDefinitionFieldConfiguration,
        NumberDefinitionFieldConfigurationNumberFormat,
        NumberDefinitionParams,
        NumberDefinitionParamsFieldConfiguration,
        NumberDefinitionParamsFieldConfigurationNumberFormat,
        NumberDefinitionWithIncludes,
        NumberValue,
        OriginalMediaLink,
        Profile,
        ProfileResponse,
        Project,
        ProjectInclude,
        ProjectResponse,
        ProjectStatus,
        ProjectUserRolesResponse,
        ProjectWithIncludes,
        ProjectWithIncludesResponse,
        ProjectsWithIncludesResponse,
        RatingDefinition,
        RatingDefinitionFieldConfiguration,
        RatingDefinitionFieldConfigurationStyle,
        RatingDefinitionParams,
        RatingDefinitionParamsFieldConfiguration,
        RatingDefinitionParamsFieldConfigurationStyle,
        RatingDefinitionWithIncludes,
        RemoveAssetResponse,
        RemoveAssetResponseData,
        RenditionMediaLink,
        RequestAfterOpaqueCursor,
        RequestPageSize,
        SelectDefinition,
        SelectDefinitionFieldConfiguration,
        SelectDefinitionFieldConfigurationOptionsItem,
        SelectDefinitionParams,
        SelectDefinitionParamsFieldConfiguration,
        SelectDefinitionParamsFieldConfigurationOptionsItem,
        SelectDefinitionWithIncludes,
        SelectMultiDefinition,
        SelectMultiDefinitionFieldConfiguration,
        SelectMultiDefinitionFieldConfigurationOptionsItem,
        SelectMultiDefinitionFieldType,
        SelectMultiDefinitionParams,
        SelectMultiDefinitionParamsFieldConfiguration,
        SelectMultiDefinitionParamsFieldConfigurationOptionsItem,
        SelectMultiDefinitionWithIncludes,
        SelectOption,
        SelectValue,
        Share,
        ShareAccess,
        ShareResponse,
        ShareReviewersResponse,
        SharesResponse,
        SingleUserValue,
        SingleUserValueMemberOptionsType,
        TextDefinition,
        TextDefinitionFieldConfiguration,
        TextDefinitionFieldType,
        TextDefinitionParams,
        TextDefinitionWithIncludes,
        TextValue,
        TimeStamp,
        ToggleDefinition,
        ToggleDefinitionFieldConfiguration,
        ToggleDefinitionParams,
        ToggleDefinitionParamsFieldConfiguration,
        ToggleDefinitionWithIncludes,
        TooManyRequests,
        TooManyRequestsErrorsItem,
        TooManyRequestsErrorsItemSource,
        Unauthorized,
        UnauthorizedErrorsItem,
        UnauthorizedErrorsItemSource,
        UnprocessableEntity,
        UnprocessableEntityErrorsItem,
        UnprocessableEntityErrorsItemSource,
        UpdateDateDefinitionParams,
        UpdateDateDefinitionParamsFieldConfiguration,
        UpdateDateDefinitionParamsFieldConfigurationDisplayFormat,
        UpdateDateDefinitionParamsFieldConfigurationTimeFormat,
        UpdateLongTextDefinitionParams,
        UpdateNumberDefinitionParams,
        UpdateNumberDefinitionParamsFieldConfiguration,
        UpdateNumberDefinitionParamsFieldConfigurationNumberFormat,
        UpdateRatingDefinitionParams,
        UpdateRatingDefinitionParamsFieldConfiguration,
        UpdateRatingDefinitionParamsFieldConfigurationStyle,
        UpdateSelectDefinitionParams,
        UpdateSelectDefinitionParamsFieldConfiguration,
        UpdateSelectDefinitionParamsFieldConfigurationOptionsItem,
        UpdateSelectMultiDefinitionParams,
        UpdateSelectMultiDefinitionParamsFieldConfiguration,
        UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem,
        UpdateTextDefinitionParams,
        UpdateToggleDefinitionParams,
        UpdateToggleDefinitionParamsFieldConfiguration,
        UpdateUserMultiDefinitionParams,
        UpdateUserMultiDefinitionParamsFieldConfiguration,
        UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem,
        UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType,
        UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType,
        UpdateUserRolesParams,
        UpdateUserRolesParamsData,
        UpdateUserRolesParamsDataRole,
        UpdateUserRolesResponse,
        UpdateUserRolesResponseData,
        UpdateUserRolesResponseDataRole,
        UpdateUserSingleDefinitionParams,
        UpdateUserSingleDefinitionParamsFieldConfiguration,
        UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem,
        UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType,
        UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType,
        UploadUrl,
        User,
        UserMultiDefinition,
        UserMultiDefinitionFieldConfiguration,
        UserMultiDefinitionFieldConfigurationCustomMembersItem,
        UserMultiDefinitionFieldConfigurationCustomMembersItemType,
        UserMultiDefinitionFieldConfigurationMemberOptionsType,
        UserMultiDefinitionFieldType,
        UserMultiDefinitionParams,
        UserMultiDefinitionParamsFieldConfiguration,
        UserMultiDefinitionParamsFieldConfigurationCustomMembersItem,
        UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType,
        UserMultiDefinitionParamsFieldConfigurationMemberOptionsType,
        UserMultiDefinitionWithIncludes,
        UserRole,
        UserRoleRole,
        UserSingleDefinition,
        UserSingleDefinitionFieldConfiguration,
        UserSingleDefinitionFieldConfigurationCustomMembersItem,
        UserSingleDefinitionFieldConfigurationCustomMembersItemType,
        UserSingleDefinitionFieldConfigurationMemberOptionsType,
        UserSingleDefinitionFieldType,
        UserSingleDefinitionParams,
        UserSingleDefinitionParamsFieldConfiguration,
        UserSingleDefinitionParamsFieldConfigurationCustomMembersItem,
        UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType,
        UserSingleDefinitionParamsFieldConfigurationMemberOptionsType,
        UserSingleDefinitionWithIncludes,
        UserValue,
        UserValueType,
        Uuid,
        VersionStack,
        VersionStackAssetsWithIncludesResponse,
        VersionStackCopyResponse,
        VersionStackResponse,
        VersionStackWithIncludes,
        VersionStackWithIncludesResponse,
        VersionStacksWithIncludesResponse,
        Webhook,
        WebhookCreateResponse,
        WebhookCreateResponseData,
        WebhookEvents,
        WebhookResponse,
        WebhookWithIncludes,
        WebhookWithIncludesResponse,
        WebhooksWithIncludesResponse,
        Workspace,
        WorkspaceInclude,
        WorkspaceParams,
        WorkspaceParamsData,
        WorkspaceResponse,
        WorkspaceUserRolesResponse,
        WorkspaceWithIncludes,
        WorkspaceWithIncludesResponse,
        WorkspacesWithIncludesResponse,
    )
    from .errors import (
        BadRequestError,
        ConflictError,
        ForbiddenError,
        NotFoundError,
        TooManyRequestsError,
        UnauthorizedError,
        UnprocessableEntityError,
    )
    from . import (
        account_permissions,
        accounts,
        comments,
        files,
        folders,
        metadata,
        metadata_fields,
        project_permissions,
        projects,
        shares,
        users,
        version_stacks,
        webhooks,
        workspace_permissions,
        workspaces,
    )
    from .client import AsyncFrameio, Frameio
    from .comments import (
        CommentsIndexRequestInclude,
        CommentsShowRequestInclude,
        CreateCommentParamsData,
        UpdateCommentParamsData,
    )
    from .environment import FrameioEnvironment
    from .files import (
        FileCopyParamsData,
        FileCreateLocalUploadParamsData,
        FileCreateParamsData,
        FileCreateRemoteUploadParamsData,
        FileMoveParamsData,
        FileUpdateParamsData,
        FilesCopyRequestCopyComments,
        FilesListRequestInclude,
        FilesListRequestSort,
        FilesShowRequestInclude,
    )
    from .folders import (
        FolderCopyParamsData,
        FolderCreateParamsData,
        FolderMoveParamsData,
        FolderUpdateParamsData,
        FoldersIndexRequestInclude,
        FoldersListRequestInclude,
        FoldersShowRequestInclude,
    )
    from .metadata import BulkUpdateMetadataParamsData, BulkUpdateMetadataParamsDataValuesItem
    from .metadata_fields import (
        CreateFieldDefinitionParamsData,
        CreateFieldDefinitionParamsData_Date,
        CreateFieldDefinitionParamsData_LongText,
        CreateFieldDefinitionParamsData_Number,
        CreateFieldDefinitionParamsData_Rating,
        CreateFieldDefinitionParamsData_Select,
        CreateFieldDefinitionParamsData_SelectMulti,
        CreateFieldDefinitionParamsData_Text,
        CreateFieldDefinitionParamsData_Toggle,
        CreateFieldDefinitionParamsData_UserMulti,
        CreateFieldDefinitionParamsData_UserSingle,
        UpdateFieldDefinitionParamsData,
        UpdateFieldDefinitionParamsData_Date,
        UpdateFieldDefinitionParamsData_LongText,
        UpdateFieldDefinitionParamsData_Number,
        UpdateFieldDefinitionParamsData_Rating,
        UpdateFieldDefinitionParamsData_Select,
        UpdateFieldDefinitionParamsData_SelectMulti,
        UpdateFieldDefinitionParamsData_Text,
        UpdateFieldDefinitionParamsData_Toggle,
        UpdateFieldDefinitionParamsData_UserMulti,
        UpdateFieldDefinitionParamsData_UserSingle,
    )
    from .projects import ProjectParamsData, ProjectUpdateParamsData, ProjectUpdateParamsDataStatus
    from .shares import (
        AddAssetParamsData,
        AddReviewersToShareParamsData,
        AddReviewersToShareParamsDataReviewers,
        CreateShareParamsData,
        CreateShareParamsData_Asset,
        RemoveReviewerParamsData,
        RemoveReviewerParamsDataReviewers,
        UpdateShareParamsData,
        UpdateShareParamsDataAccess,
    )
    from .version import __version__
    from .version_stacks import (
        VersionStackCopyParamsData,
        VersionStackCreateParamsData,
        VersionStackMoveParamsData,
        VersionStacksIndexRequestInclude,
        VersionStacksListRequestInclude,
        VersionStacksShowRequestInclude,
    )
    from .webhooks import WebhookCreateParamsData, WebhookUpdateParamsData
_dynamic_imports: typing.Dict[str, str] = {
    "Account": ".types",
    "AccountRolesItem": ".types",
    "AccountUserRole": ".types",
    "AccountUserRoleRole": ".types",
    "AccountUserRolesResponse": ".types",
    "AccountsResponse": ".types",
    "AddAssetParamsData": ".shares",
    "AddAssetResponse": ".types",
    "AddAssetResponseData": ".types",
    "AddReviewersToShareParamsData": ".shares",
    "AddReviewersToShareParamsDataReviewers": ".shares",
    "AssetCommon": ".types",
    "AssetCommonType": ".types",
    "AssetCommonWithIncludes": ".types",
    "AssetCommonWithIncludesType": ".types",
    "AssetInclude": ".types",
    "AssetShareParams": ".types",
    "AssetShareParamsAccess": ".types",
    "AssetWithIncludes": ".types",
    "AssetWithIncludes_File": ".types",
    "AssetWithIncludes_Folder": ".types",
    "AssetWithIncludes_VersionStack": ".types",
    "AsyncFrameio": ".client",
    "AuditLogsInclude": ".types",
    "AuditLogsWithIncludesResponse": ".types",
    "AuditLogwithIncludes": ".types",
    "AuditLogwithIncludesEventType": ".types",
    "AuditLogwithIncludesResourceType": ".types",
    "BadRequest": ".types",
    "BadRequestError": ".errors",
    "BadRequestErrorsItem": ".types",
    "BadRequestErrorsItemSource": ".types",
    "BooleanValue": ".types",
    "BulkUpdateMetadataParamsData": ".metadata",
    "BulkUpdateMetadataParamsDataValuesItem": ".metadata",
    "ChildrenType": ".types",
    "Comment": ".types",
    "CommentInclude": ".types",
    "CommentResponse": ".types",
    "CommentWithIncludes": ".types",
    "CommentWithIncludesResponse": ".types",
    "CommentsIndexRequestInclude": ".comments",
    "CommentsShowRequestInclude": ".comments",
    "CommentsWithIncludesResponse": ".types",
    "Conflict": ".types",
    "ConflictError": ".errors",
    "ConflictErrorsItem": ".types",
    "ConflictErrorsItemSource": ".types",
    "CreateCommentParamsData": ".comments",
    "CreateFieldDefinitionParamsData": ".metadata_fields",
    "CreateFieldDefinitionParamsData_Date": ".metadata_fields",
    "CreateFieldDefinitionParamsData_LongText": ".metadata_fields",
    "CreateFieldDefinitionParamsData_Number": ".metadata_fields",
    "CreateFieldDefinitionParamsData_Rating": ".metadata_fields",
    "CreateFieldDefinitionParamsData_Select": ".metadata_fields",
    "CreateFieldDefinitionParamsData_SelectMulti": ".metadata_fields",
    "CreateFieldDefinitionParamsData_Text": ".metadata_fields",
    "CreateFieldDefinitionParamsData_Toggle": ".metadata_fields",
    "CreateFieldDefinitionParamsData_UserMulti": ".metadata_fields",
    "CreateFieldDefinitionParamsData_UserSingle": ".metadata_fields",
    "CreateShareParamsData": ".shares",
    "CreateShareParamsData_Asset": ".shares",
    "DateDefinition": ".types",
    "DateDefinitionFieldConfiguration": ".types",
    "DateDefinitionFieldConfigurationDisplayFormat": ".types",
    "DateDefinitionFieldConfigurationTimeFormat": ".types",
    "DateDefinitionFieldType": ".types",
    "DateDefinitionParams": ".types",
    "DateDefinitionParamsFieldConfiguration": ".types",
    "DateDefinitionParamsFieldConfigurationDisplayFormat": ".types",
    "DateDefinitionParamsFieldConfigurationTimeFormat": ".types",
    "DateDefinitionWithIncludes": ".types",
    "DateValue": ".types",
    "Email": ".types",
    "EmptyJson": ".types",
    "FieldDefinition": ".types",
    "FieldDefinitionInclude": ".types",
    "FieldDefinitionResponse": ".types",
    "FieldDefinitionWithIncludes": ".types",
    "FieldDefinitionWithIncludes_Date": ".types",
    "FieldDefinitionWithIncludes_LongText": ".types",
    "FieldDefinitionWithIncludes_Number": ".types",
    "FieldDefinitionWithIncludes_Rating": ".types",
    "FieldDefinitionWithIncludes_Select": ".types",
    "FieldDefinitionWithIncludes_SelectMulti": ".types",
    "FieldDefinitionWithIncludes_Text": ".types",
    "FieldDefinitionWithIncludes_Toggle": ".types",
    "FieldDefinitionWithIncludes_UserMulti": ".types",
    "FieldDefinitionWithIncludes_UserSingle": ".types",
    "FieldDefinition_Date": ".types",
    "FieldDefinition_LongText": ".types",
    "FieldDefinition_Number": ".types",
    "FieldDefinition_Rating": ".types",
    "FieldDefinition_Select": ".types",
    "FieldDefinition_SelectMulti": ".types",
    "FieldDefinition_Text": ".types",
    "FieldDefinition_Toggle": ".types",
    "FieldDefinition_UserMulti": ".types",
    "FieldDefinition_UserSingle": ".types",
    "FieldDefinitionsWithIncludesResponse": ".types",
    "FieldValueCommon": ".types",
    "File": ".types",
    "FileAssetsWithIncludesResponse": ".types",
    "FileCopyParamsData": ".files",
    "FileCopyResponse": ".types",
    "FileCreateLocalUploadParamsData": ".files",
    "FileCreateParamsData": ".files",
    "FileCreateRemoteUploadParamsData": ".files",
    "FileMoveParamsData": ".files",
    "FileRemoteUploadResponse": ".types",
    "FileResponse": ".types",
    "FileSort": ".types",
    "FileStatus": ".types",
    "FileUpdateParamsData": ".files",
    "FileUploadStatus": ".types",
    "FileUploadStatusResponse": ".types",
    "FileWithIncludes": ".types",
    "FileWithIncludesResponse": ".types",
    "FileWithIncludesStatus": ".types",
    "FileWithMediaLinksInclude": ".types",
    "FileWithUploadUrls": ".types",
    "FileWithUploadUrlsResponse": ".types",
    "FilesCopyRequestCopyComments": ".files",
    "FilesListRequestInclude": ".files",
    "FilesListRequestSort": ".files",
    "FilesShowRequestInclude": ".files",
    "Filters": ".types",
    "FiltersEventType": ".types",
    "FiltersResourceType": ".types",
    "Folder": ".types",
    "FolderAssetsWithIncludesResponse": ".types",
    "FolderCopyParamsData": ".folders",
    "FolderCopyResponse": ".types",
    "FolderCreateParamsData": ".folders",
    "FolderMoveParamsData": ".folders",
    "FolderResponse": ".types",
    "FolderUpdateParamsData": ".folders",
    "FolderWithIncludes": ".types",
    "FolderWithIncludesResponse": ".types",
    "FoldersIndexRequestInclude": ".folders",
    "FoldersListRequestInclude": ".folders",
    "FoldersShowRequestInclude": ".folders",
    "FoldersWithIncludesResponse": ".types",
    "Forbidden": ".types",
    "ForbiddenError": ".errors",
    "ForbiddenErrorsItem": ".types",
    "ForbiddenErrorsItemSource": ".types",
    "Frameio": ".client",
    "FrameioEnvironment": ".environment",
    "Include": ".types",
    "IncludeTotalCount": ".types",
    "IntegerValue": ".types",
    "JsonErrorResponse": ".types",
    "JsonErrorResponseErrorsItem": ".types",
    "JsonErrorResponseErrorsItemSource": ".types",
    "Links": ".types",
    "LongTextDefinition": ".types",
    "LongTextDefinitionFieldConfiguration": ".types",
    "LongTextDefinitionFieldType": ".types",
    "LongTextDefinitionParams": ".types",
    "LongTextDefinitionWithIncludes": ".types",
    "MediaLinkCommon": ".types",
    "MediaLinksCollection": ".types",
    "MetadataField": ".types",
    "MetadataField_Date": ".types",
    "MetadataField_LongText": ".types",
    "MetadataField_Number": ".types",
    "MetadataField_Rating": ".types",
    "MetadataField_Select": ".types",
    "MetadataField_SelectMulti": ".types",
    "MetadataField_Text": ".types",
    "MetadataField_Toggle": ".types",
    "MetadataField_UserMulti": ".types",
    "MetadataField_UserSingle": ".types",
    "MetadataField_Users": ".types",
    "MetadataResponse": ".types",
    "MetadataWithDefinition": ".types",
    "MultiSelectValue": ".types",
    "MultiUserValue": ".types",
    "MultiUserValueMemberOptionsType": ".types",
    "NoContent": ".types",
    "NotFound": ".types",
    "NotFoundError": ".errors",
    "NotFoundErrorsItem": ".types",
    "NotFoundErrorsItemSource": ".types",
    "NumberDefinition": ".types",
    "NumberDefinitionFieldConfiguration": ".types",
    "NumberDefinitionFieldConfigurationNumberFormat": ".types",
    "NumberDefinitionParams": ".types",
    "NumberDefinitionParamsFieldConfiguration": ".types",
    "NumberDefinitionParamsFieldConfigurationNumberFormat": ".types",
    "NumberDefinitionWithIncludes": ".types",
    "NumberValue": ".types",
    "OriginalMediaLink": ".types",
    "Profile": ".types",
    "ProfileResponse": ".types",
    "Project": ".types",
    "ProjectInclude": ".types",
    "ProjectParamsData": ".projects",
    "ProjectResponse": ".types",
    "ProjectStatus": ".types",
    "ProjectUpdateParamsData": ".projects",
    "ProjectUpdateParamsDataStatus": ".projects",
    "ProjectUserRolesResponse": ".types",
    "ProjectWithIncludes": ".types",
    "ProjectWithIncludesResponse": ".types",
    "ProjectsWithIncludesResponse": ".types",
    "RatingDefinition": ".types",
    "RatingDefinitionFieldConfiguration": ".types",
    "RatingDefinitionFieldConfigurationStyle": ".types",
    "RatingDefinitionParams": ".types",
    "RatingDefinitionParamsFieldConfiguration": ".types",
    "RatingDefinitionParamsFieldConfigurationStyle": ".types",
    "RatingDefinitionWithIncludes": ".types",
    "RemoveAssetResponse": ".types",
    "RemoveAssetResponseData": ".types",
    "RemoveReviewerParamsData": ".shares",
    "RemoveReviewerParamsDataReviewers": ".shares",
    "RenditionMediaLink": ".types",
    "RequestAfterOpaqueCursor": ".types",
    "RequestPageSize": ".types",
    "SelectDefinition": ".types",
    "SelectDefinitionFieldConfiguration": ".types",
    "SelectDefinitionFieldConfigurationOptionsItem": ".types",
    "SelectDefinitionParams": ".types",
    "SelectDefinitionParamsFieldConfiguration": ".types",
    "SelectDefinitionParamsFieldConfigurationOptionsItem": ".types",
    "SelectDefinitionWithIncludes": ".types",
    "SelectMultiDefinition": ".types",
    "SelectMultiDefinitionFieldConfiguration": ".types",
    "SelectMultiDefinitionFieldConfigurationOptionsItem": ".types",
    "SelectMultiDefinitionFieldType": ".types",
    "SelectMultiDefinitionParams": ".types",
    "SelectMultiDefinitionParamsFieldConfiguration": ".types",
    "SelectMultiDefinitionParamsFieldConfigurationOptionsItem": ".types",
    "SelectMultiDefinitionWithIncludes": ".types",
    "SelectOption": ".types",
    "SelectValue": ".types",
    "Share": ".types",
    "ShareAccess": ".types",
    "ShareResponse": ".types",
    "ShareReviewersResponse": ".types",
    "SharesResponse": ".types",
    "SingleUserValue": ".types",
    "SingleUserValueMemberOptionsType": ".types",
    "TextDefinition": ".types",
    "TextDefinitionFieldConfiguration": ".types",
    "TextDefinitionFieldType": ".types",
    "TextDefinitionParams": ".types",
    "TextDefinitionWithIncludes": ".types",
    "TextValue": ".types",
    "TimeStamp": ".types",
    "ToggleDefinition": ".types",
    "ToggleDefinitionFieldConfiguration": ".types",
    "ToggleDefinitionParams": ".types",
    "ToggleDefinitionParamsFieldConfiguration": ".types",
    "ToggleDefinitionWithIncludes": ".types",
    "TooManyRequests": ".types",
    "TooManyRequestsError": ".errors",
    "TooManyRequestsErrorsItem": ".types",
    "TooManyRequestsErrorsItemSource": ".types",
    "Unauthorized": ".types",
    "UnauthorizedError": ".errors",
    "UnauthorizedErrorsItem": ".types",
    "UnauthorizedErrorsItemSource": ".types",
    "UnprocessableEntity": ".types",
    "UnprocessableEntityError": ".errors",
    "UnprocessableEntityErrorsItem": ".types",
    "UnprocessableEntityErrorsItemSource": ".types",
    "UpdateCommentParamsData": ".comments",
    "UpdateDateDefinitionParams": ".types",
    "UpdateDateDefinitionParamsFieldConfiguration": ".types",
    "UpdateDateDefinitionParamsFieldConfigurationDisplayFormat": ".types",
    "UpdateDateDefinitionParamsFieldConfigurationTimeFormat": ".types",
    "UpdateFieldDefinitionParamsData": ".metadata_fields",
    "UpdateFieldDefinitionParamsData_Date": ".metadata_fields",
    "UpdateFieldDefinitionParamsData_LongText": ".metadata_fields",
    "UpdateFieldDefinitionParamsData_Number": ".metadata_fields",
    "UpdateFieldDefinitionParamsData_Rating": ".metadata_fields",
    "UpdateFieldDefinitionParamsData_Select": ".metadata_fields",
    "UpdateFieldDefinitionParamsData_SelectMulti": ".metadata_fields",
    "UpdateFieldDefinitionParamsData_Text": ".metadata_fields",
    "UpdateFieldDefinitionParamsData_Toggle": ".metadata_fields",
    "UpdateFieldDefinitionParamsData_UserMulti": ".metadata_fields",
    "UpdateFieldDefinitionParamsData_UserSingle": ".metadata_fields",
    "UpdateLongTextDefinitionParams": ".types",
    "UpdateNumberDefinitionParams": ".types",
    "UpdateNumberDefinitionParamsFieldConfiguration": ".types",
    "UpdateNumberDefinitionParamsFieldConfigurationNumberFormat": ".types",
    "UpdateRatingDefinitionParams": ".types",
    "UpdateRatingDefinitionParamsFieldConfiguration": ".types",
    "UpdateRatingDefinitionParamsFieldConfigurationStyle": ".types",
    "UpdateSelectDefinitionParams": ".types",
    "UpdateSelectDefinitionParamsFieldConfiguration": ".types",
    "UpdateSelectDefinitionParamsFieldConfigurationOptionsItem": ".types",
    "UpdateSelectMultiDefinitionParams": ".types",
    "UpdateSelectMultiDefinitionParamsFieldConfiguration": ".types",
    "UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem": ".types",
    "UpdateShareParamsData": ".shares",
    "UpdateShareParamsDataAccess": ".shares",
    "UpdateTextDefinitionParams": ".types",
    "UpdateToggleDefinitionParams": ".types",
    "UpdateToggleDefinitionParamsFieldConfiguration": ".types",
    "UpdateUserMultiDefinitionParams": ".types",
    "UpdateUserMultiDefinitionParamsFieldConfiguration": ".types",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem": ".types",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType": ".types",
    "UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType": ".types",
    "UpdateUserRolesParams": ".types",
    "UpdateUserRolesParamsData": ".types",
    "UpdateUserRolesParamsDataRole": ".types",
    "UpdateUserRolesResponse": ".types",
    "UpdateUserRolesResponseData": ".types",
    "UpdateUserRolesResponseDataRole": ".types",
    "UpdateUserSingleDefinitionParams": ".types",
    "UpdateUserSingleDefinitionParamsFieldConfiguration": ".types",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem": ".types",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType": ".types",
    "UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType": ".types",
    "UploadUrl": ".types",
    "User": ".types",
    "UserMultiDefinition": ".types",
    "UserMultiDefinitionFieldConfiguration": ".types",
    "UserMultiDefinitionFieldConfigurationCustomMembersItem": ".types",
    "UserMultiDefinitionFieldConfigurationCustomMembersItemType": ".types",
    "UserMultiDefinitionFieldConfigurationMemberOptionsType": ".types",
    "UserMultiDefinitionFieldType": ".types",
    "UserMultiDefinitionParams": ".types",
    "UserMultiDefinitionParamsFieldConfiguration": ".types",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItem": ".types",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType": ".types",
    "UserMultiDefinitionParamsFieldConfigurationMemberOptionsType": ".types",
    "UserMultiDefinitionWithIncludes": ".types",
    "UserRole": ".types",
    "UserRoleRole": ".types",
    "UserSingleDefinition": ".types",
    "UserSingleDefinitionFieldConfiguration": ".types",
    "UserSingleDefinitionFieldConfigurationCustomMembersItem": ".types",
    "UserSingleDefinitionFieldConfigurationCustomMembersItemType": ".types",
    "UserSingleDefinitionFieldConfigurationMemberOptionsType": ".types",
    "UserSingleDefinitionFieldType": ".types",
    "UserSingleDefinitionParams": ".types",
    "UserSingleDefinitionParamsFieldConfiguration": ".types",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItem": ".types",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType": ".types",
    "UserSingleDefinitionParamsFieldConfigurationMemberOptionsType": ".types",
    "UserSingleDefinitionWithIncludes": ".types",
    "UserValue": ".types",
    "UserValueType": ".types",
    "Uuid": ".types",
    "VersionStack": ".types",
    "VersionStackAssetsWithIncludesResponse": ".types",
    "VersionStackCopyParamsData": ".version_stacks",
    "VersionStackCopyResponse": ".types",
    "VersionStackCreateParamsData": ".version_stacks",
    "VersionStackMoveParamsData": ".version_stacks",
    "VersionStackResponse": ".types",
    "VersionStackWithIncludes": ".types",
    "VersionStackWithIncludesResponse": ".types",
    "VersionStacksIndexRequestInclude": ".version_stacks",
    "VersionStacksListRequestInclude": ".version_stacks",
    "VersionStacksShowRequestInclude": ".version_stacks",
    "VersionStacksWithIncludesResponse": ".types",
    "Webhook": ".types",
    "WebhookCreateParamsData": ".webhooks",
    "WebhookCreateResponse": ".types",
    "WebhookCreateResponseData": ".types",
    "WebhookEvents": ".types",
    "WebhookResponse": ".types",
    "WebhookUpdateParamsData": ".webhooks",
    "WebhookWithIncludes": ".types",
    "WebhookWithIncludesResponse": ".types",
    "WebhooksWithIncludesResponse": ".types",
    "Workspace": ".types",
    "WorkspaceInclude": ".types",
    "WorkspaceParams": ".types",
    "WorkspaceParamsData": ".types",
    "WorkspaceResponse": ".types",
    "WorkspaceUserRolesResponse": ".types",
    "WorkspaceWithIncludes": ".types",
    "WorkspaceWithIncludesResponse": ".types",
    "WorkspacesWithIncludesResponse": ".types",
    "__version__": ".version",
    "account_permissions": ".account_permissions",
    "accounts": ".accounts",
    "comments": ".comments",
    "files": ".files",
    "folders": ".folders",
    "metadata": ".metadata",
    "metadata_fields": ".metadata_fields",
    "project_permissions": ".project_permissions",
    "projects": ".projects",
    "shares": ".shares",
    "users": ".users",
    "version_stacks": ".version_stacks",
    "webhooks": ".webhooks",
    "workspace_permissions": ".workspace_permissions",
    "workspaces": ".workspaces",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Account",
    "AccountRolesItem",
    "AccountUserRole",
    "AccountUserRoleRole",
    "AccountUserRolesResponse",
    "AccountsResponse",
    "AddAssetParamsData",
    "AddAssetResponse",
    "AddAssetResponseData",
    "AddReviewersToShareParamsData",
    "AddReviewersToShareParamsDataReviewers",
    "AssetCommon",
    "AssetCommonType",
    "AssetCommonWithIncludes",
    "AssetCommonWithIncludesType",
    "AssetInclude",
    "AssetShareParams",
    "AssetShareParamsAccess",
    "AssetWithIncludes",
    "AssetWithIncludes_File",
    "AssetWithIncludes_Folder",
    "AssetWithIncludes_VersionStack",
    "AsyncFrameio",
    "AuditLogsInclude",
    "AuditLogsWithIncludesResponse",
    "AuditLogwithIncludes",
    "AuditLogwithIncludesEventType",
    "AuditLogwithIncludesResourceType",
    "BadRequest",
    "BadRequestError",
    "BadRequestErrorsItem",
    "BadRequestErrorsItemSource",
    "BooleanValue",
    "BulkUpdateMetadataParamsData",
    "BulkUpdateMetadataParamsDataValuesItem",
    "ChildrenType",
    "Comment",
    "CommentInclude",
    "CommentResponse",
    "CommentWithIncludes",
    "CommentWithIncludesResponse",
    "CommentsIndexRequestInclude",
    "CommentsShowRequestInclude",
    "CommentsWithIncludesResponse",
    "Conflict",
    "ConflictError",
    "ConflictErrorsItem",
    "ConflictErrorsItemSource",
    "CreateCommentParamsData",
    "CreateFieldDefinitionParamsData",
    "CreateFieldDefinitionParamsData_Date",
    "CreateFieldDefinitionParamsData_LongText",
    "CreateFieldDefinitionParamsData_Number",
    "CreateFieldDefinitionParamsData_Rating",
    "CreateFieldDefinitionParamsData_Select",
    "CreateFieldDefinitionParamsData_SelectMulti",
    "CreateFieldDefinitionParamsData_Text",
    "CreateFieldDefinitionParamsData_Toggle",
    "CreateFieldDefinitionParamsData_UserMulti",
    "CreateFieldDefinitionParamsData_UserSingle",
    "CreateShareParamsData",
    "CreateShareParamsData_Asset",
    "DateDefinition",
    "DateDefinitionFieldConfiguration",
    "DateDefinitionFieldConfigurationDisplayFormat",
    "DateDefinitionFieldConfigurationTimeFormat",
    "DateDefinitionFieldType",
    "DateDefinitionParams",
    "DateDefinitionParamsFieldConfiguration",
    "DateDefinitionParamsFieldConfigurationDisplayFormat",
    "DateDefinitionParamsFieldConfigurationTimeFormat",
    "DateDefinitionWithIncludes",
    "DateValue",
    "Email",
    "EmptyJson",
    "FieldDefinition",
    "FieldDefinitionInclude",
    "FieldDefinitionResponse",
    "FieldDefinitionWithIncludes",
    "FieldDefinitionWithIncludes_Date",
    "FieldDefinitionWithIncludes_LongText",
    "FieldDefinitionWithIncludes_Number",
    "FieldDefinitionWithIncludes_Rating",
    "FieldDefinitionWithIncludes_Select",
    "FieldDefinitionWithIncludes_SelectMulti",
    "FieldDefinitionWithIncludes_Text",
    "FieldDefinitionWithIncludes_Toggle",
    "FieldDefinitionWithIncludes_UserMulti",
    "FieldDefinitionWithIncludes_UserSingle",
    "FieldDefinition_Date",
    "FieldDefinition_LongText",
    "FieldDefinition_Number",
    "FieldDefinition_Rating",
    "FieldDefinition_Select",
    "FieldDefinition_SelectMulti",
    "FieldDefinition_Text",
    "FieldDefinition_Toggle",
    "FieldDefinition_UserMulti",
    "FieldDefinition_UserSingle",
    "FieldDefinitionsWithIncludesResponse",
    "FieldValueCommon",
    "File",
    "FileAssetsWithIncludesResponse",
    "FileCopyParamsData",
    "FileCopyResponse",
    "FileCreateLocalUploadParamsData",
    "FileCreateParamsData",
    "FileCreateRemoteUploadParamsData",
    "FileMoveParamsData",
    "FileRemoteUploadResponse",
    "FileResponse",
    "FileSort",
    "FileStatus",
    "FileUpdateParamsData",
    "FileUploadStatus",
    "FileUploadStatusResponse",
    "FileWithIncludes",
    "FileWithIncludesResponse",
    "FileWithIncludesStatus",
    "FileWithMediaLinksInclude",
    "FileWithUploadUrls",
    "FileWithUploadUrlsResponse",
    "FilesCopyRequestCopyComments",
    "FilesListRequestInclude",
    "FilesListRequestSort",
    "FilesShowRequestInclude",
    "Filters",
    "FiltersEventType",
    "FiltersResourceType",
    "Folder",
    "FolderAssetsWithIncludesResponse",
    "FolderCopyParamsData",
    "FolderCopyResponse",
    "FolderCreateParamsData",
    "FolderMoveParamsData",
    "FolderResponse",
    "FolderUpdateParamsData",
    "FolderWithIncludes",
    "FolderWithIncludesResponse",
    "FoldersIndexRequestInclude",
    "FoldersListRequestInclude",
    "FoldersShowRequestInclude",
    "FoldersWithIncludesResponse",
    "Forbidden",
    "ForbiddenError",
    "ForbiddenErrorsItem",
    "ForbiddenErrorsItemSource",
    "Frameio",
    "FrameioEnvironment",
    "Include",
    "IncludeTotalCount",
    "IntegerValue",
    "JsonErrorResponse",
    "JsonErrorResponseErrorsItem",
    "JsonErrorResponseErrorsItemSource",
    "Links",
    "LongTextDefinition",
    "LongTextDefinitionFieldConfiguration",
    "LongTextDefinitionFieldType",
    "LongTextDefinitionParams",
    "LongTextDefinitionWithIncludes",
    "MediaLinkCommon",
    "MediaLinksCollection",
    "MetadataField",
    "MetadataField_Date",
    "MetadataField_LongText",
    "MetadataField_Number",
    "MetadataField_Rating",
    "MetadataField_Select",
    "MetadataField_SelectMulti",
    "MetadataField_Text",
    "MetadataField_Toggle",
    "MetadataField_UserMulti",
    "MetadataField_UserSingle",
    "MetadataField_Users",
    "MetadataResponse",
    "MetadataWithDefinition",
    "MultiSelectValue",
    "MultiUserValue",
    "MultiUserValueMemberOptionsType",
    "NoContent",
    "NotFound",
    "NotFoundError",
    "NotFoundErrorsItem",
    "NotFoundErrorsItemSource",
    "NumberDefinition",
    "NumberDefinitionFieldConfiguration",
    "NumberDefinitionFieldConfigurationNumberFormat",
    "NumberDefinitionParams",
    "NumberDefinitionParamsFieldConfiguration",
    "NumberDefinitionParamsFieldConfigurationNumberFormat",
    "NumberDefinitionWithIncludes",
    "NumberValue",
    "OriginalMediaLink",
    "Profile",
    "ProfileResponse",
    "Project",
    "ProjectInclude",
    "ProjectParamsData",
    "ProjectResponse",
    "ProjectStatus",
    "ProjectUpdateParamsData",
    "ProjectUpdateParamsDataStatus",
    "ProjectUserRolesResponse",
    "ProjectWithIncludes",
    "ProjectWithIncludesResponse",
    "ProjectsWithIncludesResponse",
    "RatingDefinition",
    "RatingDefinitionFieldConfiguration",
    "RatingDefinitionFieldConfigurationStyle",
    "RatingDefinitionParams",
    "RatingDefinitionParamsFieldConfiguration",
    "RatingDefinitionParamsFieldConfigurationStyle",
    "RatingDefinitionWithIncludes",
    "RemoveAssetResponse",
    "RemoveAssetResponseData",
    "RemoveReviewerParamsData",
    "RemoveReviewerParamsDataReviewers",
    "RenditionMediaLink",
    "RequestAfterOpaqueCursor",
    "RequestPageSize",
    "SelectDefinition",
    "SelectDefinitionFieldConfiguration",
    "SelectDefinitionFieldConfigurationOptionsItem",
    "SelectDefinitionParams",
    "SelectDefinitionParamsFieldConfiguration",
    "SelectDefinitionParamsFieldConfigurationOptionsItem",
    "SelectDefinitionWithIncludes",
    "SelectMultiDefinition",
    "SelectMultiDefinitionFieldConfiguration",
    "SelectMultiDefinitionFieldConfigurationOptionsItem",
    "SelectMultiDefinitionFieldType",
    "SelectMultiDefinitionParams",
    "SelectMultiDefinitionParamsFieldConfiguration",
    "SelectMultiDefinitionParamsFieldConfigurationOptionsItem",
    "SelectMultiDefinitionWithIncludes",
    "SelectOption",
    "SelectValue",
    "Share",
    "ShareAccess",
    "ShareResponse",
    "ShareReviewersResponse",
    "SharesResponse",
    "SingleUserValue",
    "SingleUserValueMemberOptionsType",
    "TextDefinition",
    "TextDefinitionFieldConfiguration",
    "TextDefinitionFieldType",
    "TextDefinitionParams",
    "TextDefinitionWithIncludes",
    "TextValue",
    "TimeStamp",
    "ToggleDefinition",
    "ToggleDefinitionFieldConfiguration",
    "ToggleDefinitionParams",
    "ToggleDefinitionParamsFieldConfiguration",
    "ToggleDefinitionWithIncludes",
    "TooManyRequests",
    "TooManyRequestsError",
    "TooManyRequestsErrorsItem",
    "TooManyRequestsErrorsItemSource",
    "Unauthorized",
    "UnauthorizedError",
    "UnauthorizedErrorsItem",
    "UnauthorizedErrorsItemSource",
    "UnprocessableEntity",
    "UnprocessableEntityError",
    "UnprocessableEntityErrorsItem",
    "UnprocessableEntityErrorsItemSource",
    "UpdateCommentParamsData",
    "UpdateDateDefinitionParams",
    "UpdateDateDefinitionParamsFieldConfiguration",
    "UpdateDateDefinitionParamsFieldConfigurationDisplayFormat",
    "UpdateDateDefinitionParamsFieldConfigurationTimeFormat",
    "UpdateFieldDefinitionParamsData",
    "UpdateFieldDefinitionParamsData_Date",
    "UpdateFieldDefinitionParamsData_LongText",
    "UpdateFieldDefinitionParamsData_Number",
    "UpdateFieldDefinitionParamsData_Rating",
    "UpdateFieldDefinitionParamsData_Select",
    "UpdateFieldDefinitionParamsData_SelectMulti",
    "UpdateFieldDefinitionParamsData_Text",
    "UpdateFieldDefinitionParamsData_Toggle",
    "UpdateFieldDefinitionParamsData_UserMulti",
    "UpdateFieldDefinitionParamsData_UserSingle",
    "UpdateLongTextDefinitionParams",
    "UpdateNumberDefinitionParams",
    "UpdateNumberDefinitionParamsFieldConfiguration",
    "UpdateNumberDefinitionParamsFieldConfigurationNumberFormat",
    "UpdateRatingDefinitionParams",
    "UpdateRatingDefinitionParamsFieldConfiguration",
    "UpdateRatingDefinitionParamsFieldConfigurationStyle",
    "UpdateSelectDefinitionParams",
    "UpdateSelectDefinitionParamsFieldConfiguration",
    "UpdateSelectDefinitionParamsFieldConfigurationOptionsItem",
    "UpdateSelectMultiDefinitionParams",
    "UpdateSelectMultiDefinitionParamsFieldConfiguration",
    "UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem",
    "UpdateShareParamsData",
    "UpdateShareParamsDataAccess",
    "UpdateTextDefinitionParams",
    "UpdateToggleDefinitionParams",
    "UpdateToggleDefinitionParamsFieldConfiguration",
    "UpdateUserMultiDefinitionParams",
    "UpdateUserMultiDefinitionParamsFieldConfiguration",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType",
    "UpdateUserRolesParams",
    "UpdateUserRolesParamsData",
    "UpdateUserRolesParamsDataRole",
    "UpdateUserRolesResponse",
    "UpdateUserRolesResponseData",
    "UpdateUserRolesResponseDataRole",
    "UpdateUserSingleDefinitionParams",
    "UpdateUserSingleDefinitionParamsFieldConfiguration",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType",
    "UploadUrl",
    "User",
    "UserMultiDefinition",
    "UserMultiDefinitionFieldConfiguration",
    "UserMultiDefinitionFieldConfigurationCustomMembersItem",
    "UserMultiDefinitionFieldConfigurationCustomMembersItemType",
    "UserMultiDefinitionFieldConfigurationMemberOptionsType",
    "UserMultiDefinitionFieldType",
    "UserMultiDefinitionParams",
    "UserMultiDefinitionParamsFieldConfiguration",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItem",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UserMultiDefinitionParamsFieldConfigurationMemberOptionsType",
    "UserMultiDefinitionWithIncludes",
    "UserRole",
    "UserRoleRole",
    "UserSingleDefinition",
    "UserSingleDefinitionFieldConfiguration",
    "UserSingleDefinitionFieldConfigurationCustomMembersItem",
    "UserSingleDefinitionFieldConfigurationCustomMembersItemType",
    "UserSingleDefinitionFieldConfigurationMemberOptionsType",
    "UserSingleDefinitionFieldType",
    "UserSingleDefinitionParams",
    "UserSingleDefinitionParamsFieldConfiguration",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItem",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UserSingleDefinitionParamsFieldConfigurationMemberOptionsType",
    "UserSingleDefinitionWithIncludes",
    "UserValue",
    "UserValueType",
    "Uuid",
    "VersionStack",
    "VersionStackAssetsWithIncludesResponse",
    "VersionStackCopyParamsData",
    "VersionStackCopyResponse",
    "VersionStackCreateParamsData",
    "VersionStackMoveParamsData",
    "VersionStackResponse",
    "VersionStackWithIncludes",
    "VersionStackWithIncludesResponse",
    "VersionStacksIndexRequestInclude",
    "VersionStacksListRequestInclude",
    "VersionStacksShowRequestInclude",
    "VersionStacksWithIncludesResponse",
    "Webhook",
    "WebhookCreateParamsData",
    "WebhookCreateResponse",
    "WebhookCreateResponseData",
    "WebhookEvents",
    "WebhookResponse",
    "WebhookUpdateParamsData",
    "WebhookWithIncludes",
    "WebhookWithIncludesResponse",
    "WebhooksWithIncludesResponse",
    "Workspace",
    "WorkspaceInclude",
    "WorkspaceParams",
    "WorkspaceParamsData",
    "WorkspaceResponse",
    "WorkspaceUserRolesResponse",
    "WorkspaceWithIncludes",
    "WorkspaceWithIncludesResponse",
    "WorkspacesWithIncludesResponse",
    "__version__",
    "account_permissions",
    "accounts",
    "comments",
    "files",
    "folders",
    "metadata",
    "metadata_fields",
    "project_permissions",
    "projects",
    "shares",
    "users",
    "version_stacks",
    "webhooks",
    "workspace_permissions",
    "workspaces",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .filters_event_type import FiltersEventType
from .filters_resource_type import FiltersResourceType


class Filters(UncheckedBaseModel):
    """
    Audit logs search filter parameters
    """

    event_type: typing.Optional[FiltersEventType] = pydantic.Field(default=None)
    """
    Filter by event type
    """

    from_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    Start date for search, Format: ISO8601 extended [YYYY-MM-DD]
    """

    ip_address: typing.Optional[str] = pydantic.Field(default=None)
    """
    Filter by IP address. This supports both IPv4 (1.1.1.1) and IPv6 (2001:db8:3333:4444:5555:6666:7777:8888)
    """

    project_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Filter by Project ID (UUID)
    """

    resource_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Filter by Resource ID (UUID)
    """

    resource_type: typing.Optional[FiltersResourceType] = pydantic.Field(default=None)
    """
    Filter by resource type
    """

    to_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    End date for search, Format: ISO8601 extended [YYYY-MM-DD]
    """

    user_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Filter by User ID (UUID)
    """

    workspace_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Filter by Workspace ID (UUID)
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .user_single_definition_field_configuration import UserSingleDefinitionFieldConfiguration
from .user_single_definition_field_type import UserSingleDefinitionFieldType


class UserSingleDefinition(UncheckedBaseModel):
    created_at: dt.datetime = pydantic.Field()
    """
    Created Timestamp
    """

    creator_id: str = pydantic.Field()
    """
    Field definition creator ID
    """

    field_configuration: UserSingleDefinitionFieldConfiguration
    field_type: UserSingleDefinitionFieldType = pydantic.Field()
    """
    Field type
    """

    id: str = pydantic.Field()
    """
    Field definition ID
    """

    mutable: bool = pydantic.Field()
    """
    Field definition mutability. System fields cannot be updated.
    """

    name: str = pydantic.Field()
    """
    FieldDefinition Name
    """

    updated_at: dt.datetime = pydantic.Field()
    """
    Updated Timestamp
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from .project_update_params_data_status import ProjectUpdateParamsDataStatus


class ProjectUpdateParamsData(UncheckedBaseModel):
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Project Name
    """

    restricted: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the project is restricted or not
    """

    status: typing.Optional[ProjectUpdateParamsDataStatus] = pydantic.Field(default=None)
    """
    Project Status
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel


class TextDefinitionParams(UncheckedBaseModel):
    name: str = pydantic.Field()
    """
    Field definition name
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from .update_share_params_data_access import UpdateShareParamsDataAccess


class UpdateShareParamsData(UncheckedBaseModel):
    access: typing.Optional[UpdateShareParamsDataAccess] = None
    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Share description - NOTE: Requires feature custom_branded_shares
    """

    downloading_enabled: typing.Optional[bool] = None
    expiration: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Expiration timestamp
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Share Name (must include at least one non-whitespace character and no line breaks)
    """

    passphrase: typing.Optional[str] = pydantic.Field(default=None)
    """
    Passphrase to access share, if passphrase is required and not given it will be generated
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.request_options import RequestOptions
from ..core.unchecked_base_model import construct_type
from ..errors.bad_request_error import BadRequestError
from ..errors.conflict_error import ConflictError
from ..errors.forbidden_error import ForbiddenError
from ..errors.not_found_error import NotFoundError
from ..errors.too_many_requests_error import TooManyRequestsError
from ..errors.unauthorized_error import UnauthorizedError
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.bad_request import BadRequest
from ..types.conflict import Conflict
from ..types.forbidden import Forbidden
from ..types.not_found import NotFound
from ..types.profile_response import ProfileResponse
from ..types.too_many_requests import TooManyRequests
from ..types.unauthorized import Unauthorized


class RawUsersClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def show(self, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[ProfileResponse]:
        """
        Inspect details of the user associated with the bearer token. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ProfileResponse]
            OK
        """
        _response = self._client_wrapper.httpx_client.request(
            "v4/me",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ProfileResponse,
                    construct_type(
                        type_=ProfileResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        BadRequest,
                        construct_type(
                            type_=BadRequest,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Unauthorized,
                        construct_type(
                            type_=Unauthorized,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Forbidden,
                        construct_type(
                            type_=Forbidden,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        NotFound,
                        construct_type(
                            type_=NotFound,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 409:
                raise ConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Conflict,
                        construct_type(
                            type_=Conflict,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        TooManyRequests,
                        construct_type(
                            type_=TooManyRequests,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawUsersClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def show(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ProfileResponse]:
        """
        Inspect details of the user associated with the bearer token. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ProfileResponse]
            OK
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v4/me",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ProfileResponse,
                    construct_type(
                        type_=ProfileResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        BadRequest,
                        construct_type(
                            type_=BadRequest,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Unauthorized,
                        construct_type(
                            type_=Unauthorized,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Forbidden,
                        construct_type(
                            type_=Forbidden,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        NotFound,
                        construct_type(
                            type_=NotFound,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 409:
                raise ConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Conflict,
                        construct_type(
                            type_=Conflict,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        TooManyRequests,
                        construct_type(
                            type_=TooManyRequests,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .account import Account
    from .account_roles_item import AccountRolesItem
    from .account_user_role import AccountUserRole
    from .account_user_role_role import AccountUserRoleRole
    from .account_user_roles_response import AccountUserRolesResponse
    from .accounts_response import AccountsResponse
    from .add_asset_response import AddAssetResponse
    from .add_asset_response_data import AddAssetResponseData
    from .asset_common import AssetCommon
    from .asset_common_type import AssetCommonType
    from .asset_common_with_includes import AssetCommonWithIncludes
    from .asset_common_with_includes_type import AssetCommonWithIncludesType
    from .asset_include import AssetInclude
    from .asset_share_params import AssetShareParams
    from .asset_share_params_access import AssetShareParamsAccess
    from .asset_with_includes import (
        AssetWithIncludes,
        AssetWithIncludes_File,
        AssetWithIncludes_Folder,
        AssetWithIncludes_VersionStack,
    )
    from .audit_logs_include import AuditLogsInclude
    from .audit_logs_with_includes_response import AuditLogsWithIncludesResponse
    from .audit_logwith_includes import AuditLogwithIncludes
    from .audit_logwith_includes_event_type import AuditLogwithIncludesEventType
    from .audit_logwith_includes_resource_type import AuditLogwithIncludesResourceType
    from .bad_request import BadRequest
    from .bad_request_errors_item import BadRequestErrorsItem
    from .bad_request_errors_item_source import BadRequestErrorsItemSource
    from .boolean_value import BooleanValue
    from .children_type import ChildrenType
    from .comment import Comment
    from .comment_include import CommentInclude
    from .comment_response import CommentResponse
    from .comment_with_includes import CommentWithIncludes
    from .comment_with_includes_response import CommentWithIncludesResponse
    from .comments_with_includes_response import CommentsWithIncludesResponse
    from .conflict import Conflict
    from .conflict_errors_item import ConflictErrorsItem
    from .conflict_errors_item_source import ConflictErrorsItemSource
    from .date_definition import DateDefinition
    from .date_definition_field_configuration import DateDefinitionFieldConfiguration
    from .date_definition_field_configuration_display_format import DateDefinitionFieldConfigurationDisplayFormat
    from .date_definition_field_configuration_time_format import DateDefinitionFieldConfigurationTimeFormat
    from .date_definition_field_type import DateDefinitionFieldType
    from .date_definition_params import DateDefinitionParams
    from .date_definition_params_field_configuration import DateDefinitionParamsFieldConfiguration
    from .date_definition_params_field_configuration_display_format import (
        DateDefinitionParamsFieldConfigurationDisplayFormat,
    )
    from .date_definition_params_field_configuration_time_format import DateDefinitionParamsFieldConfigurationTimeFormat
    from .date_definition_with_includes import DateDefinitionWithIncludes
    from .date_value import DateValue
    from .email import Email
    from .empty_json import EmptyJson
    from .field_definition import (
        FieldDefinition,
        FieldDefinition_Date,
        FieldDefinition_LongText,
        FieldDefinition_Number,
        FieldDefinition_Rating,
        FieldDefinition_Select,
        FieldDefinition_SelectMulti,
        FieldDefinition_Text,
        FieldDefinition_Toggle,
        FieldDefinition_UserMulti,
        FieldDefinition_UserSingle,
    )
    from .field_definition_include import FieldDefinitionInclude
    from .field_definition_response import FieldDefinitionResponse
    from .field_definition_with_includes import (
        FieldDefinitionWithIncludes,
        FieldDefinitionWithIncludes_Date,
        FieldDefinitionWithIncludes_LongText,
        FieldDefinitionWithIncludes_Number,
        FieldDefinitionWithIncludes_Rating,
        FieldDefinitionWithIncludes_Select,
        FieldDefinitionWithIncludes_SelectMulti,
        FieldDefinitionWithIncludes_Text,
        FieldDefinitionWithIncludes_Toggle,
        FieldDefinitionWithIncludes_UserMulti,
        FieldDefinitionWithIncludes_UserSingle,
    )
    from .field_definitions_with_includes_response import FieldDefinitionsWithIncludesResponse
    from .field_value_common import FieldValueCommon
    from .file import File
    from .file_assets_with_includes_response import FileAssetsWithIncludesResponse
    from .file_copy_response import FileCopyResponse
    from .file_remote_upload_response import FileRemoteUploadResponse
    from .file_response import FileResponse
    from .file_sort import FileSort
    from .file_status import FileStatus
    from .file_upload_status import FileUploadStatus
    from .file_upload_status_response import FileUploadStatusResponse
    from .file_with_includes import FileWithIncludes
    from .file_with_includes_response import FileWithIncludesResponse
    from .file_with_includes_status import FileWithIncludesStatus
    from .file_with_media_links_include import FileWithMediaLinksInclude
    from .file_with_upload_urls import FileWithUploadUrls
    from .file_with_upload_urls_response import FileWithUploadUrlsResponse
    from .filters import Filters
    from .filters_event_type import FiltersEventType
    from .filters_resource_type import FiltersResourceType
    from .folder import Folder
    from .folder_assets_with_includes_response import FolderAssetsWithIncludesResponse
    from .folder_copy_response import FolderCopyResponse
    from .folder_response import FolderResponse
    from .folder_with_includes import FolderWithIncludes
    from .folder_with_includes_response import FolderWithIncludesResponse
    from .folders_with_includes_response import FoldersWithIncludesResponse
    from .forbidden import Forbidden
    from .forbidden_errors_item import ForbiddenErrorsItem
    from .forbidden_errors_item_source import ForbiddenErrorsItemSource
    from .include import Include
    from .include_total_count import IncludeTotalCount
    from .integer_value import IntegerValue
    from .json_error_response import JsonErrorResponse
    from .json_error_response_errors_item import JsonErrorResponseErrorsItem
    from .json_error_response_errors_item_source import JsonErrorResponseErrorsItemSource
    from .links import Links
    from .long_text_definition import LongTextDefinition
    from .long_text_definition_field_configuration import LongTextDefinitionFieldConfiguration
    from .long_text_definition_field_type import LongTextDefinitionFieldType
    from .long_text_definition_params import LongTextDefinitionParams
    from .long_text_definition_with_includes import LongTextDefinitionWithIncludes
    from .media_link_common import MediaLinkCommon
    from .media_links_collection import MediaLinksCollection
    from .metadata_field import (
        MetadataField,
        MetadataField_Date,
        MetadataField_LongText,
        MetadataField_Number,
        MetadataField_Rating,
        MetadataField_Select,
        MetadataField_SelectMulti,
        MetadataField_Text,
        MetadataField_Toggle,
        MetadataField_UserMulti,
        MetadataField_UserSingle,
        MetadataField_Users,
    )
    from .metadata_response import MetadataResponse
    from .metadata_with_definition import MetadataWithDefinition
    from .multi_select_value import MultiSelectValue
    from .multi_user_value import MultiUserValue
    from .multi_user_value_member_options_type import MultiUserValueMemberOptionsType
    from .no_content import NoContent
    from .not_found import NotFound
    from .not_found_errors_item import NotFoundErrorsItem
    from .not_found_errors_item_source import NotFoundErrorsItemSource
    from .number_definition import NumberDefinition
    from .number_definition_field_configuration import NumberDefinitionFieldConfiguration
    from .number_definition_field_configuration_number_format import NumberDefinitionFieldConfigurationNumberFormat
    from .number_definition_params import NumberDefinitionParams
    from .number_definition_params_field_configuration import NumberDefinitionParamsFieldConfiguration
    from .number_definition_params_field_configuration_number_format import (
        NumberDefinitionParamsFieldConfigurationNumberFormat,
    )
    from .number_definition_with_includes import NumberDefinitionWithIncludes
    from .number_value import NumberValue
    from .original_media_link import OriginalMediaLink
    from .profile import Profile
    from .profile_response import ProfileResponse
    from .project import Project
    from .project_include import ProjectInclude
    from .project_response import ProjectResponse
    from .project_status import ProjectStatus
    from .project_user_roles_response import ProjectUserRolesResponse
    from .project_with_includes import ProjectWithIncludes
    from .project_with_includes_response import ProjectWithIncludesResponse
    from .projects_with_includes_response import ProjectsWithIncludesResponse
    from .rating_definition import RatingDefinition
    from .rating_definition_field_configuration import RatingDefinitionFieldConfiguration
    from .rating_definition_field_configuration_style import RatingDefinitionFieldConfigurationStyle
    from .rating_definition_params import RatingDefinitionParams
    from .rating_definition_params_field_configuration import RatingDefinitionParamsFieldConfiguration
    from .rating_definition_params_field_configuration_style import RatingDefinitionParamsFieldConfigurationStyle
    from .rating_definition_with_includes import RatingDefinitionWithIncludes
    from .remove_asset_response import RemoveAssetResponse
    from .remove_asset_response_data import RemoveAssetResponseData
    from .rendition_media_link import RenditionMediaLink
    from .request_after_opaque_cursor import RequestAfterOpaqueCursor
    from .request_page_size import RequestPageSize
    from .select_definition import SelectDefinition
    from .select_definition_field_configuration import SelectDefinitionFieldConfiguration
    from .select_definition_field_configuration_options_item import SelectDefinitionFieldConfigurationOptionsItem
    from .select_definition_params import SelectDefinitionParams
    from .select_definition_params_field_configuration import SelectDefinitionParamsFieldConfiguration
    from .select_definition_params_field_configuration_options_item import (
        SelectDefinitionParamsFieldConfigurationOptionsItem,
    )
    from .select_definition_with_includes import SelectDefinitionWithIncludes
    from .select_multi_definition import SelectMultiDefinition
    from .select_multi_definition_field_configuration import SelectMultiDefinitionFieldConfiguration
    from .select_multi_definition_field_configuration_options_item import (
        SelectMultiDefinitionFieldConfigurationOptionsItem,
    )
    from .select_multi_definition_field_type import SelectMultiDefinitionFieldType
    from .select_multi_definition_params import SelectMultiDefinitionParams
    from .select_multi_definition_params_field_configuration import SelectMultiDefinitionParamsFieldConfiguration
    from .select_multi_definition_params_field_configuration_options_item import (
        SelectMultiDefinitionParamsFieldConfigurationOptionsItem,
    )
    from .select_multi_definition_with_includes import SelectMultiDefinitionWithIncludes
    from .select_option import SelectOption
    from .select_value import SelectValue
    from .share import Share
    from .share_access import ShareAccess
    from .share_response import ShareResponse
    from .share_reviewers_response import ShareReviewersResponse
    from .shares_response import SharesResponse
    from .single_user_value import SingleUserValue
    from .single_user_value_member_options_type import SingleUserValueMemberOptionsType
    from .text_definition import TextDefinition
    from .text_definition_field_configuration import TextDefinitionFieldConfiguration
    from .text_definition_field_type import TextDefinitionFieldType
    from .text_definition_params import TextDefinitionParams
    from .text_definition_with_includes import TextDefinitionWithIncludes
    from .text_value import TextValue
    from .time_stamp import TimeStamp
    from .toggle_definition import ToggleDefinition
    from .toggle_definition_field_configuration import ToggleDefinitionFieldConfiguration
    from .toggle_definition_params import ToggleDefinitionParams
    from .toggle_definition_params_field_configuration import ToggleDefinitionParamsFieldConfiguration
    from .toggle_definition_with_includes import ToggleDefinitionWithIncludes
    from .too_many_requests import TooManyRequests
    from .too_many_requests_errors_item import TooManyRequestsErrorsItem
    from .too_many_requests_errors_item_source import TooManyRequestsErrorsItemSource
    from .unauthorized import Unauthorized
    from .unauthorized_errors_item import UnauthorizedErrorsItem
    from .unauthorized_errors_item_source import UnauthorizedErrorsItemSource
    from .unprocessable_entity import UnprocessableEntity
    from .unprocessable_entity_errors_item import UnprocessableEntityErrorsItem
    from .unprocessable_entity_errors_item_source import UnprocessableEntityErrorsItemSource
    from .update_date_definition_params import UpdateDateDefinitionParams
    from .update_date_definition_params_field_configuration import UpdateDateDefinitionParamsFieldConfiguration
    from .update_date_definition_params_field_configuration_display_format import (
        UpdateDateDefinitionParamsFieldConfigurationDisplayFormat,
    )
    from .update_date_definition_params_field_configuration_time_format import (
        UpdateDateDefinitionParamsFieldConfigurationTimeFormat,
    )
    from .update_long_text_definition_params import UpdateLongTextDefinitionParams
    from .update_number_definition_params import UpdateNumberDefinitionParams
    from .update_number_definition_params_field_configuration import UpdateNumberDefinitionParamsFieldConfiguration
    from .update_number_definition_params_field_configuration_number_format import (
        UpdateNumberDefinitionParamsFieldConfigurationNumberFormat,
    )
    from .update_rating_definition_params import UpdateRatingDefinitionParams
    from .update_rating_definition_params_field_configuration import UpdateRatingDefinitionParamsFieldConfiguration
    from .update_rating_definition_params_field_configuration_style import (
        UpdateRatingDefinitionParamsFieldConfigurationStyle,
    )
    from .update_select_definition_params import UpdateSelectDefinitionParams
    from .update_select_definition_params_field_configuration import UpdateSelectDefinitionParamsFieldConfiguration
    from .update_select_definition_params_field_configuration_options_item import (
        UpdateSelectDefinitionParamsFieldConfigurationOptionsItem,
    )
    from .update_select_multi_definition_params import UpdateSelectMultiDefinitionParams
    from .update_select_multi_definition_params_field_configuration import (
        UpdateSelectMultiDefinitionParamsFieldConfiguration,
    )
    from .update_select_multi_definition_params_field_configuration_options_item import (
        UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem,
    )
    from .update_text_definition_params import UpdateTextDefinitionParams
    from .update_toggle_definition_params import UpdateToggleDefinitionParams
    from .update_toggle_definition_params_field_configuration import UpdateToggleDefinitionParamsFieldConfiguration
    from .update_user_multi_definition_params import UpdateUserMultiDefinitionParams
    from .update_user_multi_definition_params_field_configuration import (
        UpdateUserMultiDefinitionParamsFieldConfiguration,
    )
    from .update_user_multi_definition_params_field_configuration_custom_members_item import (
        UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem,
    )
    from .update_user_multi_definition_params_field_configuration_custom_members_item_type import (
        UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType,
    )
    from .update_user_multi_definition_params_field_configuration_member_options_type import (
        UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType,
    )
    from .update_user_roles_params import UpdateUserRolesParams
    from .update_user_roles_params_data import UpdateUserRolesParamsData
    from .update_user_roles_params_data_role import UpdateUserRolesParamsDataRole
    from .update_user_roles_response import UpdateUserRolesResponse
    from .update_user_roles_response_data import UpdateUserRolesResponseData
    from .update_user_roles_response_data_role import UpdateUserRolesResponseDataRole
    from .update_user_single_definition_params import UpdateUserSingleDefinitionParams
    from .update_user_single_definition_params_field_configuration import (
        UpdateUserSingleDefinitionParamsFieldConfiguration,
    )
    from .update_user_single_definition_params_field_configuration_custom_members_item import (
        UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem,
    )
    from .update_user_single_definition_params_field_configuration_custom_members_item_type import (
        UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType,
    )
    from .update_user_single_definition_params_field_configuration_member_options_type import (
        UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType,
    )
    from .upload_url import UploadUrl
    from .user import User
    from .user_multi_definition import UserMultiDefinition
    from .user_multi_definition_field_configuration import UserMultiDefinitionFieldConfiguration
    from .user_multi_definition_field_configuration_custom_members_item import (
        UserMultiDefinitionFieldConfigurationCustomMembersItem,
    )
    from .user_multi_definition_field_configuration_custom_members_item_type import (
        UserMultiDefinitionFieldConfigurationCustomMembersItemType,
    )
    from .user_multi_definition_field_configuration_member_options_type import (
        UserMultiDefinitionFieldConfigurationMemberOptionsType,
    )
    from .user_multi_definition_field_type import UserMultiDefinitionFieldType
    from .user_multi_definition_params import UserMultiDefinitionParams
    from .user_multi_definition_params_field_configuration import UserMultiDefinitionParamsFieldConfiguration
    from .user_multi_definition_params_field_configuration_custom_members_item import (
        UserMultiDefinitionParamsFieldConfigurationCustomMembersItem,
    )
    from .user_multi_definition_params_field_configuration_custom_members_item_type import (
        UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType,
    )
    from .user_multi_definition_params_field_configuration_member_options_type import (
        UserMultiDefinitionParamsFieldConfigurationMemberOptionsType,
    )
    from .user_multi_definition_with_includes import UserMultiDefinitionWithIncludes
    from .user_role import UserRole
    from .user_role_role import UserRoleRole
    from .user_single_definition import UserSingleDefinition
    from .user_single_definition_field_configuration import UserSingleDefinitionFieldConfiguration
    from .user_single_definition_field_configuration_custom_members_item import (
        UserSingleDefinitionFieldConfigurationCustomMembersItem,
    )
    from .user_single_definition_field_configuration_custom_members_item_type import (
        UserSingleDefinitionFieldConfigurationCustomMembersItemType,
    )
    from .user_single_definition_field_configuration_member_options_type import (
        UserSingleDefinitionFieldConfigurationMemberOptionsType,
    )
    from .user_single_definition_field_type import UserSingleDefinitionFieldType
    from .user_single_definition_params import UserSingleDefinitionParams
    from .user_single_definition_params_field_configuration import UserSingleDefinitionParamsFieldConfiguration
    from .user_single_definition_params_field_configuration_custom_members_item import (
        UserSingleDefinitionParamsFieldConfigurationCustomMembersItem,
    )
    from .user_single_definition_params_field_configuration_custom_members_item_type import (
        UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType,
    )
    from .user_single_definition_params_field_configuration_member_options_type import (
        UserSingleDefinitionParamsFieldConfigurationMemberOptionsType,
    )
    from .user_single_definition_with_includes import UserSingleDefinitionWithIncludes
    from .user_value import UserValue
    from .user_value_type import UserValueType
    from .uuid_ import Uuid
    from .version_stack import VersionStack
    from .version_stack_assets_with_includes_response import VersionStackAssetsWithIncludesResponse
    from .version_stack_copy_response import VersionStackCopyResponse
    from .version_stack_response import VersionStackResponse
    from .version_stack_with_includes import VersionStackWithIncludes
    from .version_stack_with_includes_response import VersionStackWithIncludesResponse
    from .version_stacks_with_includes_response import VersionStacksWithIncludesResponse
    from .webhook import Webhook
    from .webhook_create_response import WebhookCreateResponse
    from .webhook_create_response_data import WebhookCreateResponseData
    from .webhook_events import WebhookEvents
    from .webhook_response import WebhookResponse
    from .webhook_with_includes import WebhookWithIncludes
    from .webhook_with_includes_response import WebhookWithIncludesResponse
    from .webhooks_with_includes_response import WebhooksWithIncludesResponse
    from .workspace import Workspace
    from .workspace_include import WorkspaceInclude
    from .workspace_params import WorkspaceParams
    from .workspace_params_data import WorkspaceParamsData
    from .workspace_response import WorkspaceResponse
    from .workspace_user_roles_response import WorkspaceUserRolesResponse
    from .workspace_with_includes import WorkspaceWithIncludes
    from .workspace_with_includes_response import WorkspaceWithIncludesResponse
    from .workspaces_with_includes_response import WorkspacesWithIncludesResponse
_dynamic_imports: typing.Dict[str, str] = {
    "Account": ".account",
    "AccountRolesItem": ".account_roles_item",
    "AccountUserRole": ".account_user_role",
    "AccountUserRoleRole": ".account_user_role_role",
    "AccountUserRolesResponse": ".account_user_roles_response",
    "AccountsResponse": ".accounts_response",
    "AddAssetResponse": ".add_asset_response",
    "AddAssetResponseData": ".add_asset_response_data",
    "AssetCommon": ".asset_common",
    "AssetCommonType": ".asset_common_type",
    "AssetCommonWithIncludes": ".asset_common_with_includes",
    "AssetCommonWithIncludesType": ".asset_common_with_includes_type",
    "AssetInclude": ".asset_include",
    "AssetShareParams": ".asset_share_params",
    "AssetShareParamsAccess": ".asset_share_params_access",
    "AssetWithIncludes": ".asset_with_includes",
    "AssetWithIncludes_File": ".asset_with_includes",
    "AssetWithIncludes_Folder": ".asset_with_includes",
    "AssetWithIncludes_VersionStack": ".asset_with_includes",
    "AuditLogsInclude": ".audit_logs_include",
    "AuditLogsWithIncludesResponse": ".audit_logs_with_includes_response",
    "AuditLogwithIncludes": ".audit_logwith_includes",
    "AuditLogwithIncludesEventType": ".audit_logwith_includes_event_type",
    "AuditLogwithIncludesResourceType": ".audit_logwith_includes_resource_type",
    "BadRequest": ".bad_request",
    "BadRequestErrorsItem": ".bad_request_errors_item",
    "BadRequestErrorsItemSource": ".bad_request_errors_item_source",
    "BooleanValue": ".boolean_value",
    "ChildrenType": ".children_type",
    "Comment": ".comment",
    "CommentInclude": ".comment_include",
    "CommentResponse": ".comment_response",
    "CommentWithIncludes": ".comment_with_includes",
    "CommentWithIncludesResponse": ".comment_with_includes_response",
    "CommentsWithIncludesResponse": ".comments_with_includes_response",
    "Conflict": ".conflict",
    "ConflictErrorsItem": ".conflict_errors_item",
    "ConflictErrorsItemSource": ".conflict_errors_item_source",
    "DateDefinition": ".date_definition",
    "DateDefinitionFieldConfiguration": ".date_definition_field_configuration",
    "DateDefinitionFieldConfigurationDisplayFormat": ".date_definition_field_configuration_display_format",
    "DateDefinitionFieldConfigurationTimeFormat": ".date_definition_field_configuration_time_format",
    "DateDefinitionFieldType": ".date_definition_field_type",
    "DateDefinitionParams": ".date_definition_params",
    "DateDefinitionParamsFieldConfiguration": ".date_definition_params_field_configuration",
    "DateDefinitionParamsFieldConfigurationDisplayFormat": ".date_definition_params_field_configuration_display_format",
    "DateDefinitionParamsFieldConfigurationTimeFormat": ".date_definition_params_field_configuration_time_format",
    "DateDefinitionWithIncludes": ".date_definition_with_includes",
    "DateValue": ".date_value",
    "Email": ".email",
    "EmptyJson": ".empty_json",
    "FieldDefinition": ".field_definition",
    "FieldDefinitionInclude": ".field_definition_include",
    "FieldDefinitionResponse": ".field_definition_response",
    "FieldDefinitionWithIncludes": ".field_definition_with_includes",
    "FieldDefinitionWithIncludes_Date": ".field_definition_with_includes",
    "FieldDefinitionWithIncludes_LongText": ".field_definition_with_includes",
    "FieldDefinitionWithIncludes_Number": ".field_definition_with_includes",
    "FieldDefinitionWithIncludes_Rating": ".field_definition_with_includes",
    "FieldDefinitionWithIncludes_Select": ".field_definition_with_includes",
    "FieldDefinitionWithIncludes_SelectMulti": ".field_definition_with_includes",
    "FieldDefinitionWithIncludes_Text": ".field_definition_with_includes",
    "FieldDefinitionWithIncludes_Toggle": ".field_definition_with_includes",
    "FieldDefinitionWithIncludes_UserMulti": ".field_definition_with_includes",
    "FieldDefinitionWithIncludes_UserSingle": ".field_definition_with_includes",
    "FieldDefinition_Date": ".field_definition",
    "FieldDefinition_LongText": ".field_definition",
    "FieldDefinition_Number": ".field_definition",
    "FieldDefinition_Rating": ".field_definition",
    "FieldDefinition_Select": ".field_definition",
    "FieldDefinition_SelectMulti": ".field_definition",
    "FieldDefinition_Text": ".field_definition",
    "FieldDefinition_Toggle": ".field_definition",
    "FieldDefinition_UserMulti": ".field_definition",
    "FieldDefinition_UserSingle": ".field_definition",
    "FieldDefinitionsWithIncludesResponse": ".field_definitions_with_includes_response",
    "FieldValueCommon": ".field_value_common",
    "File": ".file",
    "FileAssetsWithIncludesResponse": ".file_assets_with_includes_response",
    "FileCopyResponse": ".file_copy_response",
    "FileRemoteUploadResponse": ".file_remote_upload_response",
    "FileResponse": ".file_response",
    "FileSort": ".file_sort",
    "FileStatus": ".file_status",
    "FileUploadStatus": ".file_upload_status",
    "FileUploadStatusResponse": ".file_upload_status_response",
    "FileWithIncludes": ".file_with_includes",
    "FileWithIncludesResponse": ".file_with_includes_response",
    "FileWithIncludesStatus": ".file_with_includes_status",
    "FileWithMediaLinksInclude": ".file_with_media_links_include",
    "FileWithUploadUrls": ".file_with_upload_urls",
    "FileWithUploadUrlsResponse": ".file_with_upload_urls_response",
    "Filters": ".filters",
    "FiltersEventType": ".filters_event_type",
    "FiltersResourceType": ".filters_resource_type",
    "Folder": ".folder",
    "FolderAssetsWithIncludesResponse": ".folder_assets_with_includes_response",
    "FolderCopyResponse": ".folder_copy_response",
    "FolderResponse": ".folder_response",
    "FolderWithIncludes": ".folder_with_includes",
    "FolderWithIncludesResponse": ".folder_with_includes_response",
    "FoldersWithIncludesResponse": ".folders_with_includes_response",
    "Forbidden": ".forbidden",
    "ForbiddenErrorsItem": ".forbidden_errors_item",
    "ForbiddenErrorsItemSource": ".forbidden_errors_item_source",
    "Include": ".include",
    "IncludeTotalCount": ".include_total_count",
    "IntegerValue": ".integer_value",
    "JsonErrorResponse": ".json_error_response",
    "JsonErrorResponseErrorsItem": ".json_error_response_errors_item",
    "JsonErrorResponseErrorsItemSource": ".json_error_response_errors_item_source",
    "Links": ".links",
    "LongTextDefinition": ".long_text_definition",
    "LongTextDefinitionFieldConfiguration": ".long_text_definition_field_configuration",
    "LongTextDefinitionFieldType": ".long_text_definition_field_type",
    "LongTextDefinitionParams": ".long_text_definition_params",
    "LongTextDefinitionWithIncludes": ".long_text_definition_with_includes",
    "MediaLinkCommon": ".media_link_common",
    "MediaLinksCollection": ".media_links_collection",
    "MetadataField": ".metadata_field",
    "MetadataField_Date": ".metadata_field",
    "MetadataField_LongText": ".metadata_field",
    "MetadataField_Number": ".metadata_field",
    "MetadataField_Rating": ".metadata_field",
    "MetadataField_Select": ".metadata_field",
    "MetadataField_SelectMulti": ".metadata_field",
    "MetadataField_Text": ".metadata_field",
    "MetadataField_Toggle": ".metadata_field",
    "MetadataField_UserMulti": ".metadata_field",
    "MetadataField_UserSingle": ".metadata_field",
    "MetadataField_Users": ".metadata_field",
    "MetadataResponse": ".metadata_response",
    "MetadataWithDefinition": ".metadata_with_definition",
    "MultiSelectValue": ".multi_select_value",
    "MultiUserValue": ".multi_user_value",
    "MultiUserValueMemberOptionsType": ".multi_user_value_member_options_type",
    "NoContent": ".no_content",
    "NotFound": ".not_found",
    "NotFoundErrorsItem": ".not_found_errors_item",
    "NotFoundErrorsItemSource": ".not_found_errors_item_source",
    "NumberDefinition": ".number_definition",
    "NumberDefinitionFieldConfiguration": ".number_definition_field_configuration",
    "NumberDefinitionFieldConfigurationNumberFormat": ".number_definition_field_configuration_number_format",
    "NumberDefinitionParams": ".number_definition_params",
    "NumberDefinitionParamsFieldConfiguration": ".number_definition_params_field_configuration",
    "NumberDefinitionParamsFieldConfigurationNumberFormat": ".number_definition_params_field_configuration_number_format",
    "NumberDefinitionWithIncludes": ".number_definition_with_includes",
    "NumberValue": ".number_value",
    "OriginalMediaLink": ".original_media_link",
    "Profile": ".profile",
    "ProfileResponse": ".profile_response",
    "Project": ".project",
    "ProjectInclude": ".project_include",
    "ProjectResponse": ".project_response",
    "ProjectStatus": ".project_status",
    "ProjectUserRolesResponse": ".project_user_roles_response",
    "ProjectWithIncludes": ".project_with_includes",
    "ProjectWithIncludesResponse": ".project_with_includes_response",
    "ProjectsWithIncludesResponse": ".projects_with_includes_response",
    "RatingDefinition": ".rating_definition",
    "RatingDefinitionFieldConfiguration": ".rating_definition_field_configuration",
    "RatingDefinitionFieldConfigurationStyle": ".rating_definition_field_configuration_style",
    "RatingDefinitionParams": ".rating_definition_params",
    "RatingDefinitionParamsFieldConfiguration": ".rating_definition_params_field_configuration",
    "RatingDefinitionParamsFieldConfigurationStyle": ".rating_definition_params_field_configuration_style",
    "RatingDefinitionWithIncludes": ".rating_definition_with_includes",
    "RemoveAssetResponse": ".remove_asset_response",
    "RemoveAssetResponseData": ".remove_asset_response_data",
    "RenditionMediaLink": ".rendition_media_link",
    "RequestAfterOpaqueCursor": ".request_after_opaque_cursor",
    "RequestPageSize": ".request_page_size",
    "SelectDefinition": ".select_definition",
    "SelectDefinitionFieldConfiguration": ".select_definition_field_configuration",
    "SelectDefinitionFieldConfigurationOptionsItem": ".select_definition_field_configuration_options_item",
    "SelectDefinitionParams": ".select_definition_params",
    "SelectDefinitionParamsFieldConfiguration": ".select_definition_params_field_configuration",
    "SelectDefinitionParamsFieldConfigurationOptionsItem": ".select_definition_params_field_configuration_options_item",
    "SelectDefinitionWithIncludes": ".select_definition_with_includes",
    "SelectMultiDefinition": ".select_multi_definition",
    "SelectMultiDefinitionFieldConfiguration": ".select_multi_definition_field_configuration",
    "SelectMultiDefinitionFieldConfigurationOptionsItem": ".select_multi_definition_field_configuration_options_item",
    "SelectMultiDefinitionFieldType": ".select_multi_definition_field_type",
    "SelectMultiDefinitionParams": ".select_multi_definition_params",
    "SelectMultiDefinitionParamsFieldConfiguration": ".select_multi_definition_params_field_configuration",
    "SelectMultiDefinitionParamsFieldConfigurationOptionsItem": ".select_multi_definition_params_field_configuration_options_item",
    "SelectMultiDefinitionWithIncludes": ".select_multi_definition_with_includes",
    "SelectOption": ".select_option",
    "SelectValue": ".select_value",
    "Share": ".share",
    "ShareAccess": ".share_access",
    "ShareResponse": ".share_response",
    "ShareReviewersResponse": ".share_reviewers_response",
    "SharesResponse": ".shares_response",
    "SingleUserValue": ".single_user_value",
    "SingleUserValueMemberOptionsType": ".single_user_value_member_options_type",
    "TextDefinition": ".text_definition",
    "TextDefinitionFieldConfiguration": ".text_definition_field_configuration",
    "TextDefinitionFieldType": ".text_definition_field_type",
    "TextDefinitionParams": ".text_definition_params",
    "TextDefinitionWithIncludes": ".text_definition_with_includes",
    "TextValue": ".text_value",
    "TimeStamp": ".time_stamp",
    "ToggleDefinition": ".toggle_definition",
    "ToggleDefinitionFieldConfiguration": ".toggle_definition_field_configuration",
    "ToggleDefinitionParams": ".toggle_definition_params",
    "ToggleDefinitionParamsFieldConfiguration": ".toggle_definition_params_field_configuration",
    "ToggleDefinitionWithIncludes": ".toggle_definition_with_includes",
    "TooManyRequests": ".too_many_requests",
    "TooManyRequestsErrorsItem": ".too_many_requests_errors_item",
    "TooManyRequestsErrorsItemSource": ".too_many_requests_errors_item_source",
    "Unauthorized": ".unauthorized",
    "UnauthorizedErrorsItem": ".unauthorized_errors_item",
    "UnauthorizedErrorsItemSource": ".unauthorized_errors_item_source",
    "UnprocessableEntity": ".unprocessable_entity",
    "UnprocessableEntityErrorsItem": ".unprocessable_entity_errors_item",
    "UnprocessableEntityErrorsItemSource": ".unprocessable_entity_errors_item_source",
    "UpdateDateDefinitionParams": ".update_date_definition_params",
    "UpdateDateDefinitionParamsFieldConfiguration": ".update_date_definition_params_field_configuration",
    "UpdateDateDefinitionParamsFieldConfigurationDisplayFormat": ".update_date_definition_params_field_configuration_display_format",
    "UpdateDateDefinitionParamsFieldConfigurationTimeFormat": ".update_date_definition_params_field_configuration_time_format",
    "UpdateLongTextDefinitionParams": ".update_long_text_definition_params",
    "UpdateNumberDefinitionParams": ".update_number_definition_params",
    "UpdateNumberDefinitionParamsFieldConfiguration": ".update_number_definition_params_field_configuration",
    "UpdateNumberDefinitionParamsFieldConfigurationNumberFormat": ".update_number_definition_params_field_configuration_number_format",
    "UpdateRatingDefinitionParams": ".update_rating_definition_params",
    "UpdateRatingDefinitionParamsFieldConfiguration": ".update_rating_definition_params_field_configuration",
    "UpdateRatingDefinitionParamsFieldConfigurationStyle": ".update_rating_definition_params_field_configuration_style",
    "UpdateSelectDefinitionParams": ".update_select_definition_params",
    "UpdateSelectDefinitionParamsFieldConfiguration": ".update_select_definition_params_field_configuration",
    "UpdateSelectDefinitionParamsFieldConfigurationOptionsItem": ".update_select_definition_params_field_configuration_options_item",
    "UpdateSelectMultiDefinitionParams": ".update_select_multi_definition_params",
    "UpdateSelectMultiDefinitionParamsFieldConfiguration": ".update_select_multi_definition_params_field_configuration",
    "UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem": ".update_select_multi_definition_params_field_configuration_options_item",
    "UpdateTextDefinitionParams": ".update_text_definition_params",
    "UpdateToggleDefinitionParams": ".update_toggle_definition_params",
    "UpdateToggleDefinitionParamsFieldConfiguration": ".update_toggle_definition_params_field_configuration",
    "UpdateUserMultiDefinitionParams": ".update_user_multi_definition_params",
    "UpdateUserMultiDefinitionParamsFieldConfiguration": ".update_user_multi_definition_params_field_configuration",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem": ".update_user_multi_definition_params_field_configuration_custom_members_item",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType": ".update_user_multi_definition_params_field_configuration_custom_members_item_type",
    "UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType": ".update_user_multi_definition_params_field_configuration_member_options_type",
    "UpdateUserRolesParams": ".update_user_roles_params",
    "UpdateUserRolesParamsData": ".update_user_roles_params_data",
    "UpdateUserRolesParamsDataRole": ".update_user_roles_params_data_role",
    "UpdateUserRolesResponse": ".update_user_roles_response",
    "UpdateUserRolesResponseData": ".update_user_roles_response_data",
    "UpdateUserRolesResponseDataRole": ".update_user_roles_response_data_role",
    "UpdateUserSingleDefinitionParams": ".update_user_single_definition_params",
    "UpdateUserSingleDefinitionParamsFieldConfiguration": ".update_user_single_definition_params_field_configuration",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem": ".update_user_single_definition_params_field_configuration_custom_members_item",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType": ".update_user_single_definition_params_field_configuration_custom_members_item_type",
    "UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType": ".update_user_single_definition_params_field_configuration_member_options_type",
    "UploadUrl": ".upload_url",
    "User": ".user",
    "UserMultiDefinition": ".user_multi_definition",
    "UserMultiDefinitionFieldConfiguration": ".user_multi_definition_field_configuration",
    "UserMultiDefinitionFieldConfigurationCustomMembersItem": ".user_multi_definition_field_configuration_custom_members_item",
    "UserMultiDefinitionFieldConfigurationCustomMembersItemType": ".user_multi_definition_field_configuration_custom_members_item_type",
    "UserMultiDefinitionFieldConfigurationMemberOptionsType": ".user_multi_definition_field_configuration_member_options_type",
    "UserMultiDefinitionFieldType": ".user_multi_definition_field_type",
    "UserMultiDefinitionParams": ".user_multi_definition_params",
    "UserMultiDefinitionParamsFieldConfiguration": ".user_multi_definition_params_field_configuration",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItem": ".user_multi_definition_params_field_configuration_custom_members_item",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType": ".user_multi_definition_params_field_configuration_custom_members_item_type",
    "UserMultiDefinitionParamsFieldConfigurationMemberOptionsType": ".user_multi_definition_params_field_configuration_member_options_type",
    "UserMultiDefinitionWithIncludes": ".user_multi_definition_with_includes",
    "UserRole": ".user_role",
    "UserRoleRole": ".user_role_role",
    "UserSingleDefinition": ".user_single_definition",
    "UserSingleDefinitionFieldConfiguration": ".user_single_definition_field_configuration",
    "UserSingleDefinitionFieldConfigurationCustomMembersItem": ".user_single_definition_field_configuration_custom_members_item",
    "UserSingleDefinitionFieldConfigurationCustomMembersItemType": ".user_single_definition_field_configuration_custom_members_item_type",
    "UserSingleDefinitionFieldConfigurationMemberOptionsType": ".user_single_definition_field_configuration_member_options_type",
    "UserSingleDefinitionFieldType": ".user_single_definition_field_type",
    "UserSingleDefinitionParams": ".user_single_definition_params",
    "UserSingleDefinitionParamsFieldConfiguration": ".user_single_definition_params_field_configuration",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItem": ".user_single_definition_params_field_configuration_custom_members_item",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType": ".user_single_definition_params_field_configuration_custom_members_item_type",
    "UserSingleDefinitionParamsFieldConfigurationMemberOptionsType": ".user_single_definition_params_field_configuration_member_options_type",
    "UserSingleDefinitionWithIncludes": ".user_single_definition_with_includes",
    "UserValue": ".user_value",
    "UserValueType": ".user_value_type",
    "Uuid": ".uuid_",
    "VersionStack": ".version_stack",
    "VersionStackAssetsWithIncludesResponse": ".version_stack_assets_with_includes_response",
    "VersionStackCopyResponse": ".version_stack_copy_response",
    "VersionStackResponse": ".version_stack_response",
    "VersionStackWithIncludes": ".version_stack_with_includes",
    "VersionStackWithIncludesResponse": ".version_stack_with_includes_response",
    "VersionStacksWithIncludesResponse": ".version_stacks_with_includes_response",
    "Webhook": ".webhook",
    "WebhookCreateResponse": ".webhook_create_response",
    "WebhookCreateResponseData": ".webhook_create_response_data",
    "WebhookEvents": ".webhook_events",
    "WebhookResponse": ".webhook_response",
    "WebhookWithIncludes": ".webhook_with_includes",
    "WebhookWithIncludesResponse": ".webhook_with_includes_response",
    "WebhooksWithIncludesResponse": ".webhooks_with_includes_response",
    "Workspace": ".workspace",
    "WorkspaceInclude": ".workspace_include",
    "WorkspaceParams": ".workspace_params",
    "WorkspaceParamsData": ".workspace_params_data",
    "WorkspaceResponse": ".workspace_response",
    "WorkspaceUserRolesResponse": ".workspace_user_roles_response",
    "WorkspaceWithIncludes": ".workspace_with_includes",
    "WorkspaceWithIncludesResponse": ".workspace_with_includes_response",
    "WorkspacesWithIncludesResponse": ".workspaces_with_includes_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Account",
    "AccountRolesItem",
    "AccountUserRole",
    "AccountUserRoleRole",
    "AccountUserRolesResponse",
    "AccountsResponse",
    "AddAssetResponse",
    "AddAssetResponseData",
    "AssetCommon",
    "AssetCommonType",
    "AssetCommonWithIncludes",
    "AssetCommonWithIncludesType",
    "AssetInclude",
    "AssetShareParams",
    "AssetShareParamsAccess",
    "AssetWithIncludes",
    "AssetWithIncludes_File",
    "AssetWithIncludes_Folder",
    "AssetWithIncludes_VersionStack",
    "AuditLogsInclude",
    "AuditLogsWithIncludesResponse",
    "AuditLogwithIncludes",
    "AuditLogwithIncludesEventType",
    "AuditLogwithIncludesResourceType",
    "BadRequest",
    "BadRequestErrorsItem",
    "BadRequestErrorsItemSource",
    "BooleanValue",
    "ChildrenType",
    "Comment",
    "CommentInclude",
    "CommentResponse",
    "CommentWithIncludes",
    "CommentWithIncludesResponse",
    "CommentsWithIncludesResponse",
    "Conflict",
    "ConflictErrorsItem",
    "ConflictErrorsItemSource",
    "DateDefinition",
    "DateDefinitionFieldConfiguration",
    "DateDefinitionFieldConfigurationDisplayFormat",
    "DateDefinitionFieldConfigurationTimeFormat",
    "DateDefinitionFieldType",
    "DateDefinitionParams",
    "DateDefinitionParamsFieldConfiguration",
    "DateDefinitionParamsFieldConfigurationDisplayFormat",
    "DateDefinitionParamsFieldConfigurationTimeFormat",
    "DateDefinitionWithIncludes",
    "DateValue",
    "Email",
    "EmptyJson",
    "FieldDefinition",
    "FieldDefinitionInclude",
    "FieldDefinitionResponse",
    "FieldDefinitionWithIncludes",
    "FieldDefinitionWithIncludes_Date",
    "FieldDefinitionWithIncludes_LongText",
    "FieldDefinitionWithIncludes_Number",
    "FieldDefinitionWithIncludes_Rating",
    "FieldDefinitionWithIncludes_Select",
    "FieldDefinitionWithIncludes_SelectMulti",
    "FieldDefinitionWithIncludes_Text",
    "FieldDefinitionWithIncludes_Toggle",
    "FieldDefinitionWithIncludes_UserMulti",
    "FieldDefinitionWithIncludes_UserSingle",
    "FieldDefinition_Date",
    "FieldDefinition_LongText",
    "FieldDefinition_Number",
    "FieldDefinition_Rating",
    "FieldDefinition_Select",
    "FieldDefinition_SelectMulti",
    "FieldDefinition_Text",
    "FieldDefinition_Toggle",
    "FieldDefinition_UserMulti",
    "FieldDefinition_UserSingle",
    "FieldDefinitionsWithIncludesResponse",
    "FieldValueCommon",
    "File",
    "FileAssetsWithIncludesResponse",
    "FileCopyResponse",
    "FileRemoteUploadResponse",
    "FileResponse",
    "FileSort",
    "FileStatus",
    "FileUploadStatus",
    "FileUploadStatusResponse",
    "FileWithIncludes",
    "FileWithIncludesResponse",
    "FileWithIncludesStatus",
    "FileWithMediaLinksInclude",
    "FileWithUploadUrls",
    "FileWithUploadUrlsResponse",
    "Filters",
    "FiltersEventType",
    "FiltersResourceType",
    "Folder",
    "FolderAssetsWithIncludesResponse",
    "FolderCopyResponse",
    "FolderResponse",
    "FolderWithIncludes",
    "FolderWithIncludesResponse",
    "FoldersWithIncludesResponse",
    "Forbidden",
    "ForbiddenErrorsItem",
    "ForbiddenErrorsItemSource",
    "Include",
    "IncludeTotalCount",
    "IntegerValue",
    "JsonErrorResponse",
    "JsonErrorResponseErrorsItem",
    "JsonErrorResponseErrorsItemSource",
    "Links",
    "LongTextDefinition",
    "LongTextDefinitionFieldConfiguration",
    "LongTextDefinitionFieldType",
    "LongTextDefinitionParams",
    "LongTextDefinitionWithIncludes",
    "MediaLinkCommon",
    "MediaLinksCollection",
    "MetadataField",
    "MetadataField_Date",
    "MetadataField_LongText",
    "MetadataField_Number",
    "MetadataField_Rating",
    "MetadataField_Select",
    "MetadataField_SelectMulti",
    "MetadataField_Text",
    "MetadataField_Toggle",
    "MetadataField_UserMulti",
    "MetadataField_UserSingle",
    "MetadataField_Users",
    "MetadataResponse",
    "MetadataWithDefinition",
    "MultiSelectValue",
    "MultiUserValue",
    "MultiUserValueMemberOptionsType",
    "NoContent",
    "NotFound",
    "NotFoundErrorsItem",
    "NotFoundErrorsItemSource",
    "NumberDefinition",
    "NumberDefinitionFieldConfiguration",
    "NumberDefinitionFieldConfigurationNumberFormat",
    "NumberDefinitionParams",
    "NumberDefinitionParamsFieldConfiguration",
    "NumberDefinitionParamsFieldConfigurationNumberFormat",
    "NumberDefinitionWithIncludes",
    "NumberValue",
    "OriginalMediaLink",
    "Profile",
    "ProfileResponse",
    "Project",
    "ProjectInclude",
    "ProjectResponse",
    "ProjectStatus",
    "ProjectUserRolesResponse",
    "ProjectWithIncludes",
    "ProjectWithIncludesResponse",
    "ProjectsWithIncludesResponse",
    "RatingDefinition",
    "RatingDefinitionFieldConfiguration",
    "RatingDefinitionFieldConfigurationStyle",
    "RatingDefinitionParams",
    "RatingDefinitionParamsFieldConfiguration",
    "RatingDefinitionParamsFieldConfigurationStyle",
    "RatingDefinitionWithIncludes",
    "RemoveAssetResponse",
    "RemoveAssetResponseData",
    "RenditionMediaLink",
    "RequestAfterOpaqueCursor",
    "RequestPageSize",
    "SelectDefinition",
    "SelectDefinitionFieldConfiguration",
    "SelectDefinitionFieldConfigurationOptionsItem",
    "SelectDefinitionParams",
    "SelectDefinitionParamsFieldConfiguration",
    "SelectDefinitionParamsFieldConfigurationOptionsItem",
    "SelectDefinitionWithIncludes",
    "SelectMultiDefinition",
    "SelectMultiDefinitionFieldConfiguration",
    "SelectMultiDefinitionFieldConfigurationOptionsItem",
    "SelectMultiDefinitionFieldType",
    "SelectMultiDefinitionParams",
    "SelectMultiDefinitionParamsFieldConfiguration",
    "SelectMultiDefinitionParamsFieldConfigurationOptionsItem",
    "SelectMultiDefinitionWithIncludes",
    "SelectOption",
    "SelectValue",
    "Share",
    "ShareAccess",
    "ShareResponse",
    "ShareReviewersResponse",
    "SharesResponse",
    "SingleUserValue",
    "SingleUserValueMemberOptionsType",
    "TextDefinition",
    "TextDefinitionFieldConfiguration",
    "TextDefinitionFieldType",
    "TextDefinitionParams",
    "TextDefinitionWithIncludes",
    "TextValue",
    "TimeStamp",
    "ToggleDefinition",
    "ToggleDefinitionFieldConfiguration",
    "ToggleDefinitionParams",
    "ToggleDefinitionParamsFieldConfiguration",
    "ToggleDefinitionWithIncludes",
    "TooManyRequests",
    "TooManyRequestsErrorsItem",
    "TooManyRequestsErrorsItemSource",
    "Unauthorized",
    "UnauthorizedErrorsItem",
    "UnauthorizedErrorsItemSource",
    "UnprocessableEntity",
    "UnprocessableEntityErrorsItem",
    "UnprocessableEntityErrorsItemSource",
    "UpdateDateDefinitionParams",
    "UpdateDateDefinitionParamsFieldConfiguration",
    "UpdateDateDefinitionParamsFieldConfigurationDisplayFormat",
    "UpdateDateDefinitionParamsFieldConfigurationTimeFormat",
    "UpdateLongTextDefinitionParams",
    "UpdateNumberDefinitionParams",
    "UpdateNumberDefinitionParamsFieldConfiguration",
    "UpdateNumberDefinitionParamsFieldConfigurationNumberFormat",
    "UpdateRatingDefinitionParams",
    "UpdateRatingDefinitionParamsFieldConfiguration",
    "UpdateRatingDefinitionParamsFieldConfigurationStyle",
    "UpdateSelectDefinitionParams",
    "UpdateSelectDefinitionParamsFieldConfiguration",
    "UpdateSelectDefinitionParamsFieldConfigurationOptionsItem",
    "UpdateSelectMultiDefinitionParams",
    "UpdateSelectMultiDefinitionParamsFieldConfiguration",
    "UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem",
    "UpdateTextDefinitionParams",
    "UpdateToggleDefinitionParams",
    "UpdateToggleDefinitionParamsFieldConfiguration",
    "UpdateUserMultiDefinitionParams",
    "UpdateUserMultiDefinitionParamsFieldConfiguration",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItem",
    "UpdateUserMultiDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UpdateUserMultiDefinitionParamsFieldConfigurationMemberOptionsType",
    "UpdateUserRolesParams",
    "UpdateUserRolesParamsData",
    "UpdateUserRolesParamsDataRole",
    "UpdateUserRolesResponse",
    "UpdateUserRolesResponseData",
    "UpdateUserRolesResponseDataRole",
    "UpdateUserSingleDefinitionParams",
    "UpdateUserSingleDefinitionParamsFieldConfiguration",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem",
    "UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType",
    "UploadUrl",
    "User",
    "UserMultiDefinition",
    "UserMultiDefinitionFieldConfiguration",
    "UserMultiDefinitionFieldConfigurationCustomMembersItem",
    "UserMultiDefinitionFieldConfigurationCustomMembersItemType",
    "UserMultiDefinitionFieldConfigurationMemberOptionsType",
    "UserMultiDefinitionFieldType",
    "UserMultiDefinitionParams",
    "UserMultiDefinitionParamsFieldConfiguration",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItem",
    "UserMultiDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UserMultiDefinitionParamsFieldConfigurationMemberOptionsType",
    "UserMultiDefinitionWithIncludes",
    "UserRole",
    "UserRoleRole",
    "UserSingleDefinition",
    "UserSingleDefinitionFieldConfiguration",
    "UserSingleDefinitionFieldConfigurationCustomMembersItem",
    "UserSingleDefinitionFieldConfigurationCustomMembersItemType",
    "UserSingleDefinitionFieldConfigurationMemberOptionsType",
    "UserSingleDefinitionFieldType",
    "UserSingleDefinitionParams",
    "UserSingleDefinitionParamsFieldConfiguration",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItem",
    "UserSingleDefinitionParamsFieldConfigurationCustomMembersItemType",
    "UserSingleDefinitionParamsFieldConfigurationMemberOptionsType",
    "UserSingleDefinitionWithIncludes",
    "UserValue",
    "UserValueType",
    "Uuid",
    "VersionStack",
    "VersionStackAssetsWithIncludesResponse",
    "VersionStackCopyResponse",
    "VersionStackResponse",
    "VersionStackWithIncludes",
    "VersionStackWithIncludesResponse",
    "VersionStacksWithIncludesResponse",
    "Webhook",
    "WebhookCreateResponse",
    "WebhookCreateResponseData",
    "WebhookEvents",
    "WebhookResponse",
    "WebhookWithIncludes",
    "WebhookWithIncludesResponse",
    "WebhooksWithIncludesResponse",
    "Workspace",
    "WorkspaceInclude",
    "WorkspaceParams",
    "WorkspaceParamsData",
    "WorkspaceResponse",
    "WorkspaceUserRolesResponse",
    "WorkspaceWithIncludes",
    "WorkspaceWithIncludesResponse",
    "WorkspacesWithIncludesResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .audit_logwith_includes_event_type import AuditLogwithIncludesEventType
from .audit_logwith_includes_resource_type import AuditLogwithIncludesResourceType
from .user import User


class AuditLogwithIncludes(UncheckedBaseModel):
    """
    Frame.io Audit Event
    """

    account_id: str
    event_type: AuditLogwithIncludesEventType
    inserted_at: str
    ip_address: str
    project_id: typing.Optional[str] = None
    resource_id: str
    resource_type: AuditLogwithIncludesResourceType
    user: typing.Optional[User] = None
    user_id: str
    workspace_id: typing.Optional[str] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.pagination import AsyncPager, SyncPager
from ..core.request_options import RequestOptions
from ..types.include_total_count import IncludeTotalCount
from ..types.request_after_opaque_cursor import RequestAfterOpaqueCursor
from ..types.request_page_size import RequestPageSize
from ..types.uuid_ import Uuid
from ..types.workspace_params_data import WorkspaceParamsData
from ..types.workspace_response import WorkspaceResponse
from ..types.workspace_with_includes import WorkspaceWithIncludes
from ..types.workspace_with_includes_response import WorkspaceWithIncludesResponse
from ..types.workspaces_with_includes_response import WorkspacesWithIncludesResponse
from .raw_client import AsyncRawWorkspacesClient, RawWorkspacesClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class WorkspacesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawWorkspacesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawWorkspacesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawWorkspacesClient
        """
        return self._raw_client

    def show(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WorkspaceWithIncludesResponse:
        """
        Show workspace details. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceWithIncludesResponse
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.workspaces.show(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
        )
        """
        _response = self._raw_client.show(account_id, workspace_id, include=include, request_options=request_options)
        return _response.data

    def delete(
        self, account_id: Uuid, workspace_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete workspace from account. <br>Rate Limits: 60 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.workspaces.delete(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
        )
        """
        _response = self._raw_client.delete(account_id, workspace_id, request_options=request_options)
        return _response.data

    def update(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        data: WorkspaceParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WorkspaceResponse:
        """
        Update a workspace. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        data : WorkspaceParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceResponse
            OK

        Examples
        --------
        from frameio import Frameio, WorkspaceParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.workspaces.update(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=WorkspaceParamsData(
                name="My Workspace",
            ),
        )
        """
        _response = self._raw_client.update(account_id, workspace_id, data=data, request_options=request_options)
        return _response.data

    def index(
        self,
        account_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[WorkspaceWithIncludes, WorkspacesWithIncludesResponse]:
        """
        List workspaces for a given account. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[WorkspaceWithIncludes, WorkspacesWithIncludesResponse]
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        response = client.workspaces.index(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            after="<opaque_cursor>",
            page_size=10,
            include_total_count=False,
        )
        for item in response:
            yield item
        # alternatively, you can paginate page-by-page
        for page in response.iter_pages():
            yield page
        """
        return self._raw_client.index(
            account_id,
            include=include,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )

    def create(
        self, account_id: Uuid, *, data: WorkspaceParamsData, request_options: typing.Optional[RequestOptions] = None
    ) -> WorkspaceResponse:
        """
        Create workspace from an account. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        data : WorkspaceParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceResponse
            Created

        Examples
        --------
        from frameio import Frameio, WorkspaceParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.workspaces.create(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=WorkspaceParamsData(
                name="My Workspace",
            ),
        )
        """
        _response = self._raw_client.create(account_id, data=data, request_options=request_options)
        return _response.data


class AsyncWorkspacesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawWorkspacesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawWorkspacesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawWorkspacesClient
        """
        return self._raw_client

    async def show(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WorkspaceWithIncludesResponse:
        """
        Show workspace details. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.workspaces.show(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.show(
            account_id, workspace_id, include=include, request_options=request_options
        )
        return _response.data

    async def delete(
        self, account_id: Uuid, workspace_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete workspace from account. <br>Rate Limits: 60 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.workspaces.delete(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(account_id, workspace_id, request_options=request_options)
        return _response.data

    async def update(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        data: WorkspaceParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WorkspaceResponse:
        """
        Update a workspace. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        data : WorkspaceParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio, WorkspaceParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.workspaces.update(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=WorkspaceParamsData(
                    name="My Workspace",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(account_id, workspace_id, data=data, request_options=request_options)
        return _response.data

    async def index(
        self,
        account_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["creator"]] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[WorkspaceWithIncludes, WorkspacesWithIncludesResponse]:
        """
        List workspaces for a given account. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        include : typing.Optional[typing.Literal["creator"]]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[WorkspaceWithIncludes, WorkspacesWithIncludesResponse]
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            response = await client.workspaces.index(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                after="<opaque_cursor>",
                page_size=10,
                include_total_count=False,
            )
            async for item in response:
                yield item

            # alternatively, you can paginate page-by-page
            async for page in response.iter_pages():
                yield page


        asyncio.run(main())
        """
        return await self._raw_client.index(
            account_id,
            include=include,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )

    async def create(
        self, account_id: Uuid, *, data: WorkspaceParamsData, request_options: typing.Optional[RequestOptions] = None
    ) -> WorkspaceResponse:
        """
        Create workspace from an account. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        data : WorkspaceParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceResponse
            Created

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio, WorkspaceParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.workspaces.create(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=WorkspaceParamsData(
                    name="My Workspace",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(account_id, data=data, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .update_user_roles_response_data_role import UpdateUserRolesResponseDataRole


class UpdateUserRolesResponseData(UncheckedBaseModel):
    role: typing.Optional[UpdateUserRolesResponseDataRole] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

FileSort = typing.Union[
    typing.Literal[
        "name_asc",
        "created_at_asc",
        "updated_at_asc",
        "file_size_asc",
        "name_desc",
        "created_at_desc",
        "updated_at_desc",
        "file_size_desc",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .update_user_single_definition_params_field_configuration_custom_members_item import (
    UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem,
)
from .update_user_single_definition_params_field_configuration_member_options_type import (
    UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType,
)


class UpdateUserSingleDefinitionParamsFieldConfiguration(UncheckedBaseModel):
    custom_members: typing.Optional[
        typing.List[UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem]
    ] = None
    member_options_type: UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType
    notify_members: bool = pydantic.Field()
    """
    
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

UpdateDateDefinitionParamsFieldConfigurationTimeFormat = typing.Union[
    typing.Literal["twelve_hour", "twenty_four_hour"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType = typing.Union[
    typing.Literal["user", "account_user_group"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .file import File
from .upload_url import UploadUrl


class FileWithUploadUrls(File):
    upload_urls: typing.Optional[typing.List[UploadUrl]] = pydantic.Field(default=None)
    """
    File upload URLs. Number of URLs returned will vary depending on the file size.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
